<?xml version="1.0" encoding="UTF-8"?>
<sch:schema xmlns:sch="http://purl.oclc.org/dsdl/schematron" xmlns:fct="localFunctions" 
            xmlns:xsl="http://www.w3.org/1999/XSL/Transform" queryBinding="xslt2" id="NTDB" schemaVersion="2023" 
            see="URL to human-readable documentation for this document">
<sch:ns prefix="fct" uri="localFunctions"/>
 
 
<xsl:function name="fct:parseDate" as="xs:string">
	<xsl:param name="input"/>
	<xsl:choose>
		<xsl:when test="$input castable as xs:date">
			<xsl:value-of select="$input"/>
		</xsl:when>
		<xsl:when test="$input castable as xs:string">
			<xsl:choose>
				<xsl:when test="string-length($input)=8">
					<xsl:variable name="year" as="xs:string" select="substring($input,1,4)"/>
					<xsl:variable name="month" as="xs:string" select="substring($input,5,2)"/>
					<xsl:variable name="day" as="xs:string" select="substring($input,7,2)"/>
					<xsl:value-of select="string-join(($year,$month,$day),'-')"/>		
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="''"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="''"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>


<xsl:function name="fct:notLessThanDate" as="xs:boolean">
	<xsl:param name="firstDate"/>
	<xsl:param name="secondDate"/>
	<xsl:variable name="firstDateMod" select="fct:parseDate($firstDate)"/>
	<xsl:variable name="secondDateMod" select="fct:parseDate($secondDate)"/>
		<xsl:choose>
		<xsl:when test="($firstDateMod castable as xs:date) and ($secondDateMod castable as xs:date) ">
			<xsl:value-of select="not(xs:date($firstDateMod) &lt; xs:date($secondDateMod))"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="true()"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>

<xsl:function name="fct:notPirorToNextCalendarDay" as="xs:boolean">
	<xsl:param name="firstDate"/>
	<xsl:variable name="firstDateMod" select="fct:parseDate($firstDate)"/>	
		<xsl:choose>
		<xsl:when test="$firstDateMod castable as xs:date">
			<xsl:value-of select="xs:date($firstDateMod) &gt; xs:date(current-dateTime() + xs:dayTimeDuration('PT24H'))"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="false()"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>

<xsl:function name="fct:notEqualDate" as="xs:boolean">
	<xsl:param name="firstDate"/>
	<xsl:param name="secondDate"/>
	<xsl:variable name="firstDateMod" select="fct:parseDate($firstDate)"/>
	<xsl:variable name="secondDateMod" select="fct:parseDate($secondDate)"/>
	<xsl:choose>
		<xsl:when test="($firstDateMod castable as xs:date) and ($secondDateMod castable as xs:date)">
			<xsl:value-of select="not(xs:date($firstDateMod) = xs:date($secondDateMod))"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="true()"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>


<xsl:function name="fct:padTime" as="xs:time">
	<xsl:param name="input" as="xs:string"/>
	<xsl:choose>
		<xsl:when test="$input castable as xs:time">
			<xsl:value-of select="$input"/>
		</xsl:when>
		<xsl:when test="string-length($input)=5">
			<xsl:value-of select="string-join(($input,'00'), ':')"/>
		</xsl:when>
		<xsl:when test="string-length($input)=6">
			<xsl:variable name="hours" as="xs:string" select="substring($input,1,2)"/>
			<xsl:variable name="minutes" as="xs:string" select="substring($input,3,2)"/>
			<xsl:variable name="seconds" as="xs:string" select="substring($input,5,2)"/>
			<xsl:value-of select="string-join(($hours,$minutes,$seconds),':')"/>
		</xsl:when>
		<xsl:when test="string-length($input)=4">
			<xsl:variable name="hours" as="xs:string" select="substring($input,1,2)"/>
			<xsl:variable name="minutes" as="xs:string" select="substring($input,3,2)"/>
			<xsl:variable name="seconds" as="xs:string" select="'00'"/>
			<xsl:value-of select="string-join(($hours,$minutes,$seconds),':')"/>
		</xsl:when>		
		<xsl:otherwise>
			<xsl:value-of select="''"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>

<xsl:function name="fct:notLessThanTime" as="xs:boolean">
	<xsl:param name="firstTime" as="xs:string?"/>
	<xsl:param name="secondTime" as="xs:string?"/>
	<xsl:choose>
		<xsl:when test="$firstTime = '' or not($firstTime)">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:when test="$secondTime = '' or not($secondTime)">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:when test="not(xs:time(fct:padTime($firstTime)) &lt; xs:time(fct:padTime($secondTime)))">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="false()"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>

<xsl:function name="fct:notEqualTime" as="xs:boolean">
	<xsl:param name="firstTime" as="xs:string?"/>
	<xsl:param name="secondTime" as="xs:string?"/>
	<xsl:choose>
		<xsl:when test="$firstTime = '' or not($firstTime)">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:when test="$secondTime = '' or not($secondTime)">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:when test="not(xs:time(fct:padTime($firstTime)) = xs:time(fct:padTime($secondTime)))">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="false()"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>


<xsl:function name="fct:matches" as="xs:boolean">
	<xsl:param name="data" as="xs:string"/>
	<xsl:param name="regex" as="xs:string"/>
	<xsl:choose>
		<xsl:when test="matches($data,$regex)">
			<xsl:value-of select="true()"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="false()"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>


<xsl:function name="fct:durationParse" as="xs:integer">
	<xsl:param name="startDate"/>
	<xsl:param name="endDate"/>
	<xsl:param name="type" as="xs:string"/>
	<xsl:variable name="startDateMod" select="fct:parseDate($startDate)"/>
	<xsl:variable name="endDateMod" select="fct:parseDate($endDate)"/>

	<xsl:choose>
		<xsl:when test="($startDateMod castable as xs:date) and ($endDateMod castable as xs:date)">
			<xsl:variable name="startDateModYear" select="year-from-date(xs:date($startDateMod))"/>
			<xsl:variable name="startDateModMonth" select="month-from-date(xs:date($startDateMod))"/>
			<xsl:variable name="startDateModDay" select="day-from-date(xs:date($startDateMod))"/>
			<xsl:variable name="endDateModYear" select="year-from-date(xs:date($endDateMod))"/>
			<xsl:variable name="endDateModMonth" select="month-from-date(xs:date($endDateMod))"/>
			<xsl:variable name="endDateModDay" select="day-from-date(xs:date($endDateMod))"/>
			<xsl:choose>
				<xsl:when test="$type = '5'">
					<xsl:value-of select="xs:integer((xs:date($endDateMod) - xs:date($startDateMod)) div xs:dayTimeDuration('PT1M'))"/>
				</xsl:when>
		
				<xsl:when test="$type = '1'">
					<xsl:value-of select="xs:integer((xs:date($endDateMod) - xs:date($startDateMod)) div xs:dayTimeDuration('PT1H'))"/>
				</xsl:when>
	
				<xsl:when test="$type = '2'">
					<xsl:value-of select="xs:integer((xs:date($endDateMod) - xs:date($startDateMod)) div xs:dayTimeDuration('P1D'))"/>
				</xsl:when>
		
				<xsl:when test="$type = '3'">
					<xsl:choose>
						<xsl:when test="$endDateModDay &lt; $startDateModDay">
							<xsl:value-of select="$endDateModMonth - $startDateModMonth - 1"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="($endDateModMonth - $startDateModMonth) + 12 * ($endDateModYear - $startDateModYear)"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
			
				<xsl:when test="$type = '4'">
					<xsl:choose>
						<xsl:when test="$endDateModMonth &lt; $startDateModMonth">
							<xsl:value-of select="$endDateModYear - $startDateModYear - 1"/>
						</xsl:when>
						<xsl:when test="($endDateModMonth = $startDateModMonth) and ($endDateModDay &lt; $startDateModDay)">
							<xsl:value-of select="$endDateModYear - $startDateModYear - 1"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$endDateModYear - $startDateModYear"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="-1"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>		
		<xsl:otherwise>
			<xsl:value-of select="-1"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>

<xsl:function name="fct:getYear" as="xs:integer">
	<xsl:param name="date"/>
	<xsl:variable name="dateMod">
		<xsl:choose>
			<xsl:when test="$date castable as xs:date">
				<xsl:value-of select="$date"/>
			</xsl:when>
			<xsl:when test="$date castable as xs:string">
				<xsl:value-of select="fct:parseDate($date)"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$date"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="$dateMod castable as xs:date">
			<xsl:value-of select="year-from-date($dateMod)"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="0"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:function>

  <sch:title>NTDB ISO Schematron file</sch:title>

  <sch:ns prefix="ntdb" uri="PLACEHOLDER"/>
  <sch:ns prefix="xsi" uri="http://www.w3.org/2001/XMLSchema-instance"/>

  
  
  <sch:let name="ntdbElements" value="()"/>
  <sch:let name="ntdbElementsMissing" value="''"/>


  
  
  
  <sch:pattern id="HomeZip">
	<sch:title>HomeZip Assertions</sch:title>	
	
	<sch:rule id="HomeZip_self_rules" context="HomeZip">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0002_HomeZip" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			0002: Field cannot be blank
		</sch:assert>
	</sch:rule>
	
</sch:pattern>
  <sch:pattern id="HomeCountry">
	<sch:title>IncidentCountry Assertions</sch:title>	
	
	<sch:rule id="HomeCountry_self_rules" context="HomeCountry">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0102_HomeCountry" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			0102: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="0104_HomeCountry" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			0104: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:let name="homeZip" value="../HomeZip !='' or ../HomeZip[@biu]=('1', '2')"/>
		<sch:let name="ntdbElements" value=".,../InjuryZip"/>
		<sch:assert id="0105_HomeCountry" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu = '2') or not($homeZip)">
			0105: Field cannot be "Not Known/Not Recorded" when Home Zip/Postal Code is not "Not Applicable" or "Not Known/Not Recorded"
		</sch:assert>
		
	</sch:rule>
	
</sch:pattern>
  <sch:pattern id="HomeState">
	<sch:title>IncidentState Assertions</sch:title>	
	
	<sch:rule id="HomeState_self_rule" context="HomeState">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0202_HomeState" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../HomeCountry != '') then(. != '' or @biu=('1', '2')) else(true())">
			0202: Field cannot be blank
		</sch:assert>
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0204_HomeState" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(not(./../HomeCountry = 'US')) then(@biu='1') else(true())">
			0204: Field must be Not Applicable
		</sch:assert>
			
		<sch:assert id="0205_HomeState" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../HomeZip != '') then(@biu=('1')) else(true())">
			0205: Field must be Not Applicable when patient's homeZip/postcode is reported
		</sch:assert>	
	</sch:rule>
		
</sch:pattern>
  <sch:pattern id="HomeCounty">
	<sch:title>IncidentCounty Assertions</sch:title>	

	<sch:rule id="HomeCounty_self_rules" context="HomeCounty">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0302_HomeCounty" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../HomeCountry != '') then(. != '' or @biu=('1', '2')) else(true())">
			0302: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0304_HomeCounty" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(not(./../HomeCountry = 'US')) then(@biu='1') else(true())">
			0304: Field must be Not Applicable
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0305_HomeCounty" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../HomeZip != '') then(@biu=('1')) else(true())">
			0305: Field must be Not Applicable when patient's homeZip/postcode is reported
		</sch:assert>			
	</sch:rule>
	
</sch:pattern>
  <sch:pattern id="HomeCity">
	<sch:title>HomeCity Assertions</sch:title>	
	
	<sch:rule id="HomeCity_self_rules" context="HomeCity">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0402_HomeCity" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../HomeCountry != '') then(. != '' or @biu=('1', '2')) else(true())">
			0402: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0404_HomeCity" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(not(./../HomeCountry = 'US')) then(@biu='1') else(true())">
			0404: Field must be Not Applicable
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0405_HomeCity" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../HomeZip != '') then(@biu=('1')) else(true())">
			0405: Field must be Not Applicable when patient's homeZip/postcode is reported
		</sch:assert>				
	</sch:rule>
</sch:pattern>
  <sch:pattern id="HomeResidence">
	<sch:title>HomeResidence Assertions</sch:title>	
	
	<sch:rule id="HomeResidence_self_rules" context="HomeResidence">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0502_HomeResidence" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			0502: Field cannot be blank
		</sch:assert>	
			
		<sch:assert id="0503_HomeResidence" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1','2')) then(every $element in ./../../item/HomeResidence satisfies $element='') else(true())">
			0503: Element cannot be Not Applicable or Not Known/Not Recorded along with any other valid value
		</sch:assert>	

	</sch:rule>	
</sch:pattern>
  <sch:pattern id="DateOfBirth_Rules">
	<sch:title>DateOfBirth Assertions</sch:title>	
	
	<sch:rule id="DateOfBirth_self_rules" context="DateOfBirth">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0603_DateOfBirth" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			0603: Field cannot be blank
		</sch:assert>


			
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0609_DateOfBirth" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../IncidentDate, .)">
			0609: Date of Birth is later than Injury Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0610_DateOfBirth" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
			0610: Date of Birth is later than ED Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0611_DateOfBirth" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">		
			0611: Date of Birth is later than Hospital Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/> 
		<sch:assert id="0612_DateOfBirth" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". = '' or ../IncidentDate = '' or (120 &gt; fct:durationParse(., ../IncidentDate, '4'))">
			0612: Date of Birth + 120 years must be less than Injury Date
		</sch:assert>
				
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0613_DateOfBirth" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			0613: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="Age">
	<sch:title>Age Assertions</sch:title>	

	<sch:rule id="Age_self_rules" context="Age">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0703_Age" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			0703: Field cannot be blank
		</sch:assert>
			
		<sch:let name="units" value="../AgeUnits"/>
		<sch:let name="ntdbElements" value=".,../AgeUnits"/>
		<sch:assert id="0705_Age" role="[WARNING]" diagnostics="ntdbDiagnostic" test=". = '' or $units='' or ($units='5' and . &lt;= 60) or ($units='1' and . &lt;= 24)        or ($units='2' and . &lt;= 30) or ($units='3' and . &lt;= 12) or ($units='4' and . &lt;= 120)">
			0705: Age is greater than expected for the Age Units specified. Age should not exceed 60 minutes, 24 hours, 30 days, 24 months, or 120 years. Please verify this is correct.
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0708_Age" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../AgeUnits/@biu='2') then(@biu='2') else(true())">
			0708: Field must be Not Known/Not Recorded when Age Units is Not Known/Not Recorded
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0709_Age" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../DateOfBirth != '') then(@biu='1') else(true())">
			0709: Field must be Not Applicable if date of birth if reported
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="AgeUnits_Rules">
	<sch:title>DateOfBirth Assertions</sch:title>	
	
	<sch:rule id="AgeUnits_self_rules" context="AgeUnits">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0803_AgeUnits" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			0803: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0806_AgeUnits" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../Age/@biu='2') then(@biu='2') else(true())">
			0806: Field must be Not Known/Not Recorded when Age is Not Known/Not Recorded
		</sch:assert>
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0809_Age" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../DateOfBirth != '') then(@biu='1') else(true())">
			0809: Field must be Not Applicable if date of birth if reported
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="Race">
	<sch:title>Race Assertions</sch:title>	

	<sch:rule id="Race_self_rules" context="Race">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0902_Race" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			0902: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0903_Race" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../../../HomeCountry = 'US') then(not(@biu='1')) else(true())">
			0903: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="0905_Race" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(every $element in ./../../item/Race satisfies $element='') else(true())">
			0905: If Race is reported, neither Not Applicable nor Not Known/NotRecorded can also be reported
		</sch:assert>		
	</sch:rule>
	
</sch:pattern>
  <sch:pattern id="Ethnicity">
	<sch:title>Ethnicity Assertions</sch:title>	
	
	<sch:rule id="Ethnicity_self_rules" context="Ethnicity">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1002_Ethnicity" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			1002: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1003_Ethnicity" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../HomeCountry = 'US') then(not(@biu='1')) else(true())">
			1003: Field cannot be Not Applicable
		</sch:assert>
		

	</sch:rule>
</sch:pattern>
  <sch:pattern id="Sex">
	<sch:title>Sex Assertions</sch:title>	
	
	<sch:rule id="Sex_self_rules" context="Sex">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1102_Sex" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			1102: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="1103_Sex" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			1103: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
	
</sch:pattern>
 
  
  <sch:pattern id="IncidentDate">
	<sch:title>IncidentDate Assertions</sch:title>	
	
	<sch:rule id="IncidentDate_self_rules" context="IncidentDate">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1203_IncidentDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			1203: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1204_IncidentDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../DateOfBirth)">
			1204: Injury Incident Date is earlier than Date of Birth
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1205_IncidentDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EmsNotifyDate, .)">
			1205: Injury Incident Date is later than EMS Dispatch Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1206_IncidentDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EmsArrivalDate, .)">
			1206: Injury Incident Date is later than EMS Unit Arrival on Scene Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1207_IncidentDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EmsLeftDate, .)">
			1207: Injury Incident Date is later than EMS Unit Scene Departure Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1208_IncidentDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../HospitalArrivalDate, .)">
			1208: Injury Incident Date is later than ED/Hospital Arrival Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1209_IncidentDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
			1209: Injury Incident Date is later than ED Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1210_IncidentDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
			1210: Injury Incident Date is later than Hospital Discharge Date
		</sch:assert>
		
		<sch:assert id="1211_IncidentDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			1211: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:assert id="1212_IncidentDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:durationParse(../HospitalArrivalDate, ., '2') &lt; 14">
			1212: Injury Incident Date is greater than 14 days earlier than ED/Hospital Arrival Date
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="IncidentTime_Rules">
	<sch:title>IncidentDate Assertions</sch:title>	

	<sch:rule id="IncidentTime_self_rules" context="IncidentTime">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1303_IncidentTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			1303: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1304_IncidentTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../IncidentDate, ../EmsNotifyDate) or fct:notLessThanTime(../EmsNotifyTime, .)">
			1304: Injury Incident Time is later than EMS Dispatch Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1305_IncidentTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../IncidentDate, ../EmsArrivalDate) or fct:notLessThanTime(../EmsArrivalTime, .)">
			1305: Injury Incident Time is later than EMS Unit Arrival on Scene Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1306_IncidentTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../IncidentDate, ../EmsLeftDate) or fct:notLessThanTime(../EmsLeftTime, .)">
			1306: Injury Incident Time is later than EMS Unit Scene Departure Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1307_IncidentTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../IncidentDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)">
			1307: Injury Incident Time is later than ED/Hospital Arrival Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1308_IncidentTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../IncidentDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)">
			1308: Injury Incident Time is later than ED Discharge Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1309_IncidentTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../IncidentDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
	        1309: Injury Incident Time is later than Hospital Discharge Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1310_IncidentTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			1310: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="WorkRelated_Rules">
	<sch:title>WorkRelated Assertions</sch:title>	

	<sch:rule id="WorkRelated_self_rules" context="WorkRelated"> 
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1402_WorkRelated" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			1402: Field cannot be blank
		</sch:assert>
			
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1407_WorkRelated" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			1407: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>	
</sch:pattern>
  <sch:pattern id="PatientsOccupationalIndustry_Rules">
	<sch:title>PatientsOccupationalIndustry Assertions</sch:title>	

	<sch:rule id="PatientsOccupationalIndustry_self_rules" context="PatientsOccupationalIndustry">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1504_PatientsOccupationalIndustry" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			1504: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1505_PatientsOccupationalIndustry" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../WorkRelated = '1') then (not(@biu='1')) else (true())">
			1505: If Work-Related is Yes, Patient's Occupational Industry cannot be Not Applicable
		</sch:assert>	

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1506_PatientsOccupationalIndustry" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../WorkRelated = '2') then (@biu='1') else (true())">
			1506: If Work-Related is No, Patient's Occupational Industry must be Not Applicable
		</sch:assert>			
	</sch:rule>
</sch:pattern>
  <sch:pattern id="PatientsOccupation">
	<sch:title>PatientsOccupation Assertions</sch:title>	

	<sch:rule id="PatientsOccupation_self_rules" context="PatientsOccupation">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1604_PatientsOccupation" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			1604: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1605_PatientsOccupation" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../WorkRelated = '1') then (not(@biu='1')) else (true())">
			1605: If Work-Related is Yes, Patient's Occupation cannot be Not Applicable
		</sch:assert>

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="1606_PatientsOccupation" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../WorkRelated = '2') then (@biu='1') else (true())">
			1606: Not Applicable must be reported if Work-Related is No
		</sch:assert>		
	</sch:rule>	
</sch:pattern>
  <sch:pattern id="PrimaryECodeIcd10_Rules_2">
	<sch:title>PrimaryECodeIcd10 Assertions</sch:title>	

	<sch:rule id="PrimaryECodeIcd10_self_rules" context="PrimaryECodeIcd10">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8902_PrimaryECodeIcd10" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			8902: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:let name="value" value="."/>
		<sch:let name="test" value="if(matches($value,&#34;Y92\.[A-Z,0-9]{1,3}&#34;)) then false() else true()"/>
		<sch:assert id="8904_PrimaryECodeIcd10" role="[ERROR]" diagnostics="ntdbDiagnostic" test="$test">
			8904: Should not be Y92.X/Y92.XX/Y92.XXX (where X is A-Z or 0-9)
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:let name="value" value="."/>
		<sch:let name="test" value="if(matches($value,&#34;Y93\.[A-Z,0-9]{1,2}&#34;)) then false() else true()"/>
		<sch:assert id="8905_PrimaryECodeIcd10" role="[WARNING]" diagnostics="ntdbDiagnostic" test="$test">
			8905: ICD-10 External Cause Code should not be Y93.X/Y93.XX (where X is A-Z or 0-9)
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8907_PrimaryECodeIcd10" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			8907: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>	
</sch:pattern>
  <sch:pattern id="PlaceOfInjuryCode">
	<sch:title>PlaceOfInjuryCode Assertions</sch:title>	

	<sch:rule id="PlaceOfInjuryCode_self_rules" context="PlaceOfInjuryCode">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9002_PlaceOfInjuryCode" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			9002: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:let name="value" value="."/>
		<sch:let name="test" value="if(matches($value,&#34;Y92\.[A-H,J-N,P-Z,0-9]{1,3}&#34;)) then true() else false()"/>
		<sch:assert id="9003_PlaceOfInjuryCode" role="[WARNING]" diagnostics="ntdbDiagnostic" test="$test or . = ''">
			9003: Place of Injury code should be Y92.X/Y92.XX/Y92.XXX (where X is A-Z [excluding I,O] or 0-9) (ICD-10 CM only)
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9006_PlaceOfInjuryCode" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			9006: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
	
</sch:pattern>
  <sch:pattern id="AdditionalECodeIcd10">
	<sch:title>AdditionalECodeIcd10 Assertions</sch:title>	

	<sch:rule id="AdditionalECodeIcd10_self_rules" context="AdditionalECodeIcd10">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9102_AdditionalECodeIcd10" role="[WARNING]" diagnostics="ntdbDiagnostic" test=". != ../../PrimaryECodeIcd10 or . != '' or @biu=('1','2')">
			9102: Additional External Cause Code ICD-10 should not be equal to Primary External Cause Code ICD-10
		</sch:assert>
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9103_AdditionalECodeIcd10" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			9103: Field cannot be blank
		</sch:assert>
		<sch:assert id="9105_AdditionalECodeIcd10" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(. = ('T74','T76'))">
			9105:  ICD-10 T74 and T76 codes cannot be submitted as Additional External Cause Codes
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="InjuryZip">
	<sch:title>InjuryZip Assertions</sch:title>	

	<sch:rule id="InjuryZip_self_rules" context="InjuryZip">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2002_InjuryZip_not_blank" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			2002: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2006_InjuryZip_not_blank" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			2006: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>	
</sch:pattern>
  <sch:pattern id="IncidentCountry">
	<sch:title>IncidentCounty Assertions</sch:title>	

	<sch:rule id="IncidentCountry_self_rules" context="IncidentCountry">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2102_IncidentCountry" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			2102: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="2104_IncidentCountry" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			2104: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:assert id="2105_IncidentCountry" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('2')) or not(../IncidentZip='' or ../InjuryZip[@biu]=('1', '2'))">
			2105: Field cannot be Not Known/Not Recorded when Incident Location ZIP/Postal Code is not "Not Known/Not Recorded"
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="IncidentState">
	<sch:title>IncidentState Assertions</sch:title>	
	
	<sch:rule id="IncidentState_self_rule" context="IncidentState">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2203_IncidentState" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			2203: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2204_IncidentState" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(not(./../IncidentCountry = 'US')) then(@biu='1') else(true())">
			2204: Field must be Not Applicable
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2205_IncidentState" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../InjuryZip != '') then(@biu='1') else(true())">
			2205: Element must be Not Applicable when Incident Location Zip/Postal Code is documented
		</sch:assert>		
		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="IncidentCounty">
	<sch:title>IncidentCounty Assertions</sch:title>	
	
	<sch:rule id="IncidentCounty_self_rules" context="IncidentCounty">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2303_IncidentCounty" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			2303: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2304_IncidentCounty" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(not(./../IncidentCountry = 'US')) then(@biu='1') else(true())">
			2304: Field must be Not Applicable (Non-US hospitals)
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2305_IncidentCounty" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../InjuryZip != '') then(@biu='1') else(true())">
			2305: Element must be Not Applicable when Incident Location Zip/Postal Code is documented
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="IncidentCity">
	<sch:title>IncidentCity Assertions</sch:title>	
	
	<sch:rule id="IncidentCity_self_rules" context="IncidentCity">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2403_IncidentCity" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			2403: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2404_IncidentState" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(not(./../IncidentCountry = 'US')) then(@biu='1') else(true())">
			2404: Field must be Not Applicable (Non-US hospitals)
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2405_IncidentCounty" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../InjuryZip != '') then(@biu='1') else(true())">
			2405: Element must be Not Applicable when Incident Location Zip/Postal Code is documented
		</sch:assert>	
	</sch:rule>	
</sch:pattern>
  <sch:pattern id="ProtectiveDevice">
	<sch:title>ProtectiveDevice Assertions</sch:title>	
	
	<sch:rule id="ProtectiveDevice_self_rules" context="ProtectiveDevice">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2502_ProtectiveDevice" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			2502: Field cannot be blank
		</sch:assert>
		<sch:assert id="2507_ProtectiveDevice" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not (@biu='1')">
			2507: Field cannot be Not Applicable
		</sch:assert>		
		<sch:assert id="2508_ProtectiveDevice" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu='2') then(every $element in ./../../item/ProtectiveDevice satisfies $element='') else(true())">
			2508: Element cannot be Not Known/Not Recorded along with any other valid value
		</sch:assert>			
	</sch:rule>

</sch:pattern>
  <sch:pattern id="ChildSpecificRestraint">
	<sch:title>ChildSpecificRestraint Assertions</sch:title>	

	<sch:rule id="ChildSpecificRestraint_self_rules" context="ChildSpecificRestraint">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2603_ChildSpecificRestraint" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			2603: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2604_ChildSpecificRestraint" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1') or (every $element in (../ProtectiveDevices/item/ProtectiveDevice) satisfies $element != '6')">
			2604: Field cannot be Not Applicable when Protective Device is 6 (Child Restraint)
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="AirbagDeployment">
	<sch:title>AirbagDeployment Assertions</sch:title>	

	<sch:rule id="AirbagDeployment_self_rules" context="AirbagDeployment">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2703_AirbagDeployment_not_blank" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			2703: Field cannot be blank
		</sch:assert>
		<sch:assert id="2704_AirbagDeployment_not_blank" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu='2') then(every $element in ./../../item/AirbagDeployment satisfies $element='') else(true())">
			2704:  Field cannot be "Not Applicable" when Protective Device is "8. Airbag Present"
		</sch:assert>
		<sch:assert id="2705_AirbagDeployment" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu='2') then(every $element in ./../../item/AirbagDeployment satisfies $element='') else(true())">
			2705: Element cannot be Not Known/Not Recorded along with any other valid value
		</sch:assert>
	</sch:rule>	
</sch:pattern>
  <sch:pattern id="AbuseReport">
	<sch:title>AbuseReport Assertions</sch:title>	
	
	<sch:rule id="AbuseReport_self_rules" context="AbuseReport">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9202_AbuseReport" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			9202: Field cannot be Not Applicable
		</sch:assert>
		<sch:assert id="9203_AbuseReport" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			9203: Field cannot be blank
		</sch:assert>
	</sch:rule>	
</sch:pattern>
  <sch:pattern id="AbuseInvestigation">
	<sch:title>AbuseInvestigation Assertions</sch:title>	

	<sch:rule id="AbuseInvestigation_self_rules" context="AbuseInvestigation">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9302_AbuseInvestigation" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			9302: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9304_AbuseInvestigation" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../AbuseReport ='2') then(@biu='1') else(true())">
			9304: Field must be Not Applicable when Report of Physical Abuse is No
		</sch:assert>
	</sch:rule>	
</sch:pattern>
  <sch:pattern id="CaregiverAtDischarge">
	<sch:title>CaregiverAtDischarge Assertions</sch:title>		
	<sch:rule id="CaregiverAtDischarge_self_rules" context="CaregiverAtDischarge">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9402_CaregiverAtDischarge" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			9402: Field cannot be blank
		</sch:assert>

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9404_AbuseInvestigation" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../AbuseReport ='2') then(@biu='1') else(true())">
			9404: Field must be Not Applicable when Report of Physical Abuse is No
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  
  
  <sch:pattern id="EmsNotifyDate">
	<sch:title>EmsNotifyDate Assertions</sch:title>	

	<sch:rule id="EmsNotifyDate_self_rules" context="EmsNotifyDate">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2809_EmsNotifyDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			2809: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2803_EmsNotifyDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../DateOfBirth)">
			2803: EMS Dispatch Date is earlier than Date of Birth
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2804_EmsNotifyDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EmsArrivalDate, .)">
			2804: EMS Dispatch Date is later than EMS Unit Arrival on Scene Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2805_EmsNotifyDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EmsLeftDate, .)">
			2805: EMS Dispatch Date is later than EMS Unit Scene Departure Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2806_EmsNotifyDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../HospitalArrivalDate, .)">
			2806: EMS Dispatch Date is later than ED/Hospital Arrival Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2807_EmsNotifyDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
			2807: EMS Dispatch Date is later than ED Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2808_EmsNotifyDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
			2808: EMS Dispatch Date is later than Hospital Discharge Date
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsNotifyTime">
	<sch:title>EmsNotifyTime Assertions</sch:title>	

	<sch:rule id="EmsNotifyTime_self_rules" context="EmsNotifyTime">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2908_EmsNotifyTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			2908: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2903_EmsNotifyTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsNotifyDate, ../EmsArrivalDate) or fct:notLessThanTime(../EmsArrivalTime, .)">
			2903: EMS Dispatch Time is later than EMS Unit Arrival on Scene Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2904_EmsNotifyTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsNotifyDate, ../EmsLeftDate) or fct:notLessThanTime(../EmsLeftTime, .)">
			2904: EMS Dispatch Time is later than EMS Unit Scene Departure Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2905_EmsNotifyTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsNotifyDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)">
			2905: EMS Dispatch Time is later than ED/Hospital Arrival Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2906_EmsNotifyTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsNotifyDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)">
			2906: EMS Dispatch Time is later than ED Discharge Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="2907_EmsNotifyTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsNotifyDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
			2907: EMS Dispatch Time is later than Hospital Discharge Time
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsArrivalDate">
	<sch:title>EmsArrivalDate Assertions</sch:title>	

	<sch:rule id="EmsArrivalDate_self_rules" context="EmsArrivalDate">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3010_EmsArrivalDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			3010: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3003_EmsArrivalDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../DateOfBirth)">
			3003: EMS Unit Arrival on Scene Date is earlier than Date of Birth
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3004_EmsArrivalDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsNotifyDate)">
			3004: EMS Unit Arrival on Scene Date is earlier than EMS Dispatch Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3005_EmsArrivalDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EmsLeftDate, .)">
			3005: EMS Unit Arrival on Scene Date is later than EMS Unit Scene Departure Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3006_EmsArrivalDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../HospitalArrivalDate, .)">
			3006: EMS Unit Arrival on Scene Date is later than ED/Hospital Arrival Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3007_EmsArrivalDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
			3007: EMS Unit Arrival on Scene Date is later than ED Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3008_EmsArrivalDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
			3008: EMS Unit Arrival on Scene Date is later than Hospital Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/> 
		<sch:assert id="3009_EmsArrivalDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test=". = '' or ../EmsNotifyDate = '' or (fct:durationParse(../EmsNotifyDate, ., '2') &lt; 7)">
			3009: EMS Unit Arrival on Scene Date minus EMS Dispatch Date is greater than 7 days
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsArrivalTime">
	<sch:title>EmsArrivalTime Assertions</sch:title>	

	<sch:rule id="EmsArrivalTime_self_rules" context="EmsArrivalTime">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3108_EmsArrivalTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			3108: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3103_EmsArrivalTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsArrivalDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)">
			3103: EMS Unit Arrival on Scene Time is earlier than EMS Dispatch Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3104_EmsArrivalTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsArrivalDate, ../EmsLeftDate) or fct:notLessThanTime(../EmsLeftTime, .)">
			3104: EMS Unit Arrival on Scene Time is later than EMS Unit Scene Departure Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3105_EmsArrivalTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsArrivalDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)">
			3105: EMS Unit Arrival on Scene Time is later than ED/Hospital Arrival Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3106_EmsArrivalTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsArrivalDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)">
			3106: EMS Unit Arrival on Scene Time is later than ED Discharge Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3107_EmsArrivalTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsArrivalDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
			3107: EMS Unit Arrival on Scene Time is later than Hospital Discharge Time
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsLeftDate">
	<sch:title>EmsLeftDate Assertions</sch:title>	

	<sch:rule id="EmsLeftDate_self_rules" context="EmsLeftDate">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3210_EmsLeftDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			3210: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3203_EmsLeftDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../DateOfBirth)">
			3203: EMS Unit Scene Departure Date is earlier than Date of Birth
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3204_EmsLeftDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsNotifyDate)">
			3204: EMS Unit Scene Departure Date is earlier than EMS Dispatch Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3205_EmsLeftDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsArrivalDate)">
			3205: EMS Unit Scene Departure Date is earlier than EMS Unit Arrival on Scene Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3206_EmsLeftDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../HospitalArrivalDate, .)">
			3206: EMS Unit Scene Departure Date is later than ED/Hospital Arrival Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3207_EmsLeftDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
			3207: EMS Unit Scene Departure Date is later than ED Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3208_EmsLeftDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
			3208: EMS Unit Scene Departure Date is later than Hospital Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/> 
		<sch:assert id="3209_EmsLeftDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test=". = '' or ../EmsArrivalDate = '' or  (fct:durationParse(., ../EmsArrivalDate, '2') &lt; 7)">
			3209: EMS Unit Scene Departure Date minus EMS Unit Arrival on Scene Date is greater than 7 days
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsLeftTime">
	<sch:title>EmsLeftTime Assertions</sch:title>	

	<sch:rule id="EmsLeftTime_self_rules" context="EmsLeftTime">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3308_EmsLeftTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			3308: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3303_EmsLeftTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsLeftDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)">
			3303: EMS Unit Scene Departure Time is earlier than EMS Dispatch Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3304_EmsLeftTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsLeftDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)">
			3304: EMS Unit Scene Departure Time is earlier than EMS Unit Arrival on Scene Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3305_EmsLeftTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsLeftDate, ../HospitalArrivalDate) or fct:notLessThanTime(../HospitalArrivalTime, .)">
			3305: EMS Unit Scene Departure Time is later than ED/Hospital Arrival Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3306_EmsLeftTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsLeftDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)">
			3306: EMS Unit Scene Departure Time is later than the ED Discharge Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3307_EmsLeftTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EmsLeftDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
			3307: EMS Unit Scene Departure Time is later than Hospital Discharge Time
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="TransportMode">
	<sch:title>TransportMode Assertions</sch:title>	

	<sch:rule id="TransportMode_self_rules" context="TransportMode">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3402_TransportMode" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			3402: Field cannot be blank
		</sch:assert>
				
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3404_TransportMode" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			3404: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="OtherTransportMode">
	<sch:title>OtherTransportMode Assertions</sch:title>	
	
	<sch:rule id="OtherTransportMode_self_rules" context="OtherTransportMode">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3502_OtherTransportMode" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			3502: Field cannot be blank
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsSbp">
	<sch:title>EmsSbp Assertions</sch:title>	

	<sch:rule id="EmsSbp_self_rules" context="EmsSbp">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3602_EmsSbp" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			3602: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="3603_EmsSbp" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt; 220) else (true())">
			3603: The value is above 220
		</sch:assert>
		
		<sch:assert id="3607_EmsSbp" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &gt; 30) else (true())">
			3607: SBP value is below 30
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsPulseRate">
	<sch:title>EmsSbp Assertions</sch:title>	

	<sch:rule id="EmsPulseRate_self_rules" context="EmsPulseRate">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3702_EmsPulseRate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			3702: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="3703_EmsPulseRate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt; 220) else (true())">
			3703: The value submitted is above 220
		</sch:assert>
		
		<sch:assert id="3707_EmsPulseRate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &gt; 30) else (true())">
			3707: Pulse rate submitted is below 30
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsRespiratoryRate">
	<sch:title>EMS RespiratoryRate Assertions</sch:title>	

	<sch:rule id="EmsRespiratoryRate_self_rules" context="EmsRespiratoryRate">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3802_EmsRespiratoryRate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			3802: Field cannot be blank
		</sch:assert>			
		<sch:assert id="3807_EmsRespiratoryRate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &gt; 5) else (true())">
			3807: The value submitted is below 5
		</sch:assert>
		<sch:assert id="3807_EmsRespiratoryRate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt; 75) else (true())">
			3808: The value is above 75
		</sch:assert>	
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsPulseOximetry">
	<sch:title>EmsPulseOximetry Assertions</sch:title>	

	<sch:rule id="EmsPulseOximetry_self_rules" context="EmsPulseOximetry">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="3902_EmsPulseOximetry" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			3902: Field cannot be blank
		</sch:assert>
		<sch:assert id="3907_EmsRespiratoryRate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &gt; 40) else (true())">
			3907: The value submitted is below 40
		</sch:assert>			
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsGcsEye">
	<sch:title>EmsGcsEye Assertions</sch:title>	

	<sch:rule id="EmsGcsEye_self_rules" context="EmsGcsEye">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4003_EmsGcsEye" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			4003: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4006_EmsGcsEye" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../EmsGcs40Eye !='') then(@biu='2') else(true())">
			4006: Element must be Not Known/Not Recorded when Initial Field GCS 40 – Eye is reported.
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsGcsVerbal">
	<sch:title>EmsGcsVerbal Assertions</sch:title>	

	<sch:rule id="EmsGcsVerbal_self_rules" context="EmsGcsVerbal">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4103_EmsGcsVerbal" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			4103: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4106_EmsGcsVerbal" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../EmsGcs40Verbal !='') then(@biu='2') else(true())">
			4106: Element must be Not Known/Not Recorded when Initial Field GCS 40 – Verbal is reported.
		</sch:assert>			
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsGcsMotor">
	<sch:title>EmsGcsMotor Assertions</sch:title>	

	<sch:rule id="EmsGcsMotor_self_rules" context="EmsGcsMotor">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4203_EmsGcsMotor" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			4203: Field cannot be blank
		</sch:assert>
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4206_EmsGcsMotor" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../EmsGcs40Motor !='') then(@biu='2') else(true())">
			4206: Element must be Not Known/Not Recorded when Initial Field GCS 40 – Motor is reported.
		</sch:assert>			
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmsTotalGcs">
	<sch:title>EmsTotalGcs Assertions</sch:title>	

	<sch:rule id="EmsTotalGcs_self_rules" context="EmsTotalGcs">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4304_EmsTotalGcs" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			4304: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="4303_TotalGcs" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(../EmsGcsEye castable as xs:integer and ../EmsGcsVerbal castable as xs:integer and ../EmsGcsMotor castable as xs:integer and . castable as xs:integer)    then (xs:integer(.) = xs:integer(../EmsGcsEye) + xs:integer(../EmsGcsVerbal) + xs:integer(../EmsGcsMotor)) else (true())">
			4303: Initial Field GCS - Total does not equal the sum of Initial Field GCS - Eye, Initial Field GCS - Verbal, and Initial Field GCS - Motor
		</sch:assert>
		
		<sch:assert id="4306_TotalGcs" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../EmsGcs40Eye !='' or ./../EmsGcs40Verbal !='' or ./../EmsGcs40Motor !='') then(@biu='2') else(true())">
			4306: Element must be Not Known/Not Recorded when Initial Field GCS 40 – Eye, Initial Field GCS 40 – Verbal, or Initial Field GCS 40 – Motor are reported
		</sch:assert>			
	</sch:rule>
</sch:pattern>

<sch:pattern id="EmsGcs40Eye">
	<sch:title>EmsGcs40Eye Assertions</sch:title>	

	<sch:rule id="EmsGcs40Eye_self_rules" context="EmsGcs40Eye">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="15003_EmsGcs40Eye" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			15003: Field cannot be blank
		</sch:assert>

		<sch:assert id="15006_EmsGcs40Eye" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../EmsGcsEye !='') then(@biu='2') else(true())">
			15006: Element must be Not Known/Not Recorded when Initial Field GCS – Eye is reported.
		</sch:assert>

	</sch:rule>
</sch:pattern>


<sch:pattern id="EmsGcs40Verbal">
	<sch:title>EmsGcs40Motor Assertions</sch:title>	

	<sch:rule id="EmsGcs40Verbal_self_rules" context="EmsGcs40Verbal">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="15103_EmsGcs40Verbal" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			15103: Field cannot be blank
		</sch:assert>

		<sch:assert id="15106_EmsGcs40Verbal" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../EmsGcsVerbal !='') then(@biu='2') else(true())">
			15106: Element must be Not Known/Not Recorded when Initial Field GCS – Verbal is reported.
		</sch:assert>

	</sch:rule>
</sch:pattern>
<sch:pattern id="EmsGcs40Motor">
	<sch:title>EmsGcs40Motor Assertions</sch:title>	

	<sch:rule id="EmsGcs40Motor_self_rules" context="EmsGcs40Motor">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="15203_EmsGcs40Motor" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			15203: Field cannot be blank
		</sch:assert>

		<sch:assert id="15206_EmsGcs40Motor" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../EmsGcsMotor !='') then(@biu='2') else(true())">
			15206: Element must be Not Known/Not Recorded when Initial Field GCS – Motor is reported.
		</sch:assert>

	</sch:rule>
</sch:pattern>

  <sch:pattern id="InterFacilityTransfer">
	<sch:title>InterFacilityTransfer Assertions</sch:title>	
	
	<sch:rule id="InterFacilityTransfer_self_rules" context="InterFacilityTransfer">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4401_InterFacilityTransfer" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			4401: Field cannot be blank
		</sch:assert>
				
		<sch:assert id="4405_InterFacilityTransfer" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			4405: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="TraumaCenterCriterion">
	<sch:title>TraumaCenterCriterion Assertions</sch:title>	

	<sch:rule id="TraumaCenterCriterion_self_rules" context="TraumaCenterCriterion">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9502_TraumaCenterCriterion" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			9502: Field cannot be blank
		</sch:assert>
		<sch:assert id="9506_TraumaCenterCriterion" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(every $element in ./../../item/TraumaCenterCriterion satisfies $element='') else(true())">
			9506: Element cannot be Not Applicable or Not Known/Not Recorded along with any other valid value
		</sch:assert>	
	</sch:rule>
</sch:pattern>
  <sch:pattern id="VehicularPedestrianOther">
	<sch:title>VehicularPedestrianOther Assertions</sch:title>	

	<sch:rule id="VehicularPedestrianOther_self_rules" context="VehicularPedestrianOther">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9602_VehicularPedestrianOther" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			9602: Field cannot be blank
		</sch:assert>
		<sch:assert id="9607_VehicularPedestrianOther" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1', '2')) then(every $element in ./../../item/VehicularPedestrianOther satisfies $element='') else(true())">
			9607: Element cannot be Not Applicable or Not Known/Not Recorded along with any other valid value
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="PrehospitalCardiacArrest">
	<sch:title>PrehospitalCardiacArrest Assertions</sch:title>	

	<sch:rule id="PrehospitalCardiacArrest_self_rules" context="PrehospitalCardiacArrest">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9702_PrehospitalCardiacArrest" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu = ('1', '2')">
			9702: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="9703_PrehospitalCardiacArrest" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			9703: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  
<sch:pattern id="EmsDbp">
	<sch:title>EmsDbp Assertions</sch:title>	

	<sch:rule id="EmsDbp_self_rules" context="EmsDbp">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9802_EmsDbp" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu = ('1', '2')">
			9802: Element cannot be blank
		</sch:assert>
		
	</sch:rule>
</sch:pattern>

  <sch:pattern id="HospitalArrivalDate">
	<sch:title>HospitalArrivalDate Assertions</sch:title>	
	
	<sch:rule id="HospitalArrivalDate_self_rules" context="HospitalArrivalDate">
    
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4503_HospitalArrivalDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			4503: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4505_HospitalArrivalDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('2'))">
			4505: Field cannot be Not Known/Not Recorded
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4506_HospitalArrivalDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsNotifyDate)">
			4506: ED/Hospital Arrival Date is earlier than EMS Dispatch Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4507_HospitalArrivalDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsArrivalDate)">
			4507: ED/Hospital Arrival Date is earlier than EMS Unit Arrival on Scene Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4508_HospitalArrivalDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsLeftDate)">
			4508: ED/Hospital Arrival Date is earlier than EMS Unit Scene Departure Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4509_HospitalArrivalDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../EdDischargeOrdersWrittenDate, .)">
			4509: ED/Hospital Arrival Date is later than ED Discharge Date
		</sch:assert>		
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4510_HospitalArrivalDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
			4510: ED/Hospital Arrival Date is later than Hospital Discharge Date
		</sch:assert>		
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4511_HospitalArrivalDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../DateOfBirth)">
			4511: ED/Hospital Arrival Date is earlier than Date of Birth
		</sch:assert>			
		
		<sch:let name="ntdbElements" value="."/> 
		<sch:assert id="4513_HospitalArrivalDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test=". = '' or not (.) or ../IncidentDate = '' or not (../IncidentDate) or not (fct:durationParse(../IncidentDate, ., '2') &gt;= 30)">
			4513: ED/Hospital Arrival Date minus Injury Incident Date should be less than 30 days
		</sch:assert>				
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4515_HospitalArrivalDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			4515: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="HospitalArrivalTime">
	<sch:title>HospitalArrivalTime Assertions</sch:title>	
	
	<sch:rule id="HospitalArrivalTime_self_rules" context="HospitalArrivalTime">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4603_HospitalArrivalTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			4603: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4604_HospitalArrivalTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalArrivalDate, ../EmsNotifyDate) or  fct:notLessThanTime(., ../EmsNotifyTime)">
			4604: ED/Hospital Arrival Time is earlier than EMS Dispatch Time
		</sch:assert>	
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4605_HospitalArrivalTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalArrivalDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)">
			4605: ED/Hospital Arrival Time is earlier than EMS Unit Arrival on Scene Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4606_HospitalArrivalTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalArrivalDate, ../EmsLeftDate) or fct:notLessThanTime(., ../EmsLeftTime)">
			4606: ED/Hospital Arrival Time is earlier than EMS Unit Scene Departure Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4607_HospitalArrivalTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalArrivalDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(../EdDischargeOrdersWrittenTime, .)">
			4607: ED/Hospital Arrival Time is later than ED Discharge Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4608_HospitalArrivalTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalArrivalDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
			4608: ED/Hospital Arrival Time is later than Hospital Discharge Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4609_HospitalArrivalTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			4609: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="Sbp">
	<sch:title>Sbp Assertions</sch:title>	
	
	<sch:rule id="Sbp_self_rules" context="Sbp">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4702_Sbp" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			4702: Field cannot be blank
		</sch:assert>
				
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4704_Sbp" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt; 220) else (true())">
			4704: The value is above 220
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4705_Sbp" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			4705: Field cannot be Not Applicable
		</sch:assert>	

		<sch:assert id="4707_Sbp" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &gt; 30) else (true())">
			4707: SBP value is below 30
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="PulseRate">
	<sch:title>PulseRate Assertions</sch:title>	
	
	<sch:rule id="PulseRate_self_rules" context="PulseRate">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4802_PulseRate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			4802: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4804_PulseRate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt; 220) else (true())">
			4804: The value is above 220
		</sch:assert>	
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4805_PulseRate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			4805: Field cannot be Not Applicable
		</sch:assert>
		<sch:assert id="4804_PulseRate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &gt; 30) else (true())">
			4807: The value is below 30
		</sch:assert>
		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="Temperature">
	<sch:title>Temperature Assertions</sch:title>	
	
	<sch:rule id="Temperature_self_rules" context="Temperature">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4902_Temperature" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			4902: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4903_Temperature" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:decimal) then(. &lt; 42.0) else (true())">
			4903: The value is above 42.0
		</sch:assert>	
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="4904_Temperature" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			4904: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:assert id="4906_Temperature" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:decimal) then(. &gt; 20.0) else (true())">
			4906: Temperature below 20.0 Celsius
		</sch:assert>			
	</sch:rule>
</sch:pattern>
  <sch:pattern id="RespiratoryRate">
	<sch:title>RespiratoryRate Assertions</sch:title>	
	
	<sch:rule id="RespiratoryRate_self_rules" context="RespiratoryRate">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5002_RespiratoryRate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			5002:Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value=".,../Age"/>
		<sch:assert id="5001_RespiratoryRate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(../Age castable as xs:integer and ../AgeUnits castable as xs:integer and . castable as xs:integer) then ((../Age &gt;= 6 and ../AgeUnits=4 and . &lt;= 99) or ((../Age &lt; 6 or ../AgeUnits!=4) and . &lt;= 120)) else (if(. castable as xs:integer) then(. &lt; 120) else(true()))">
			5001: Invalid value. RR cannot be &gt; 99 for age in years &gt;= 6 OR RR cannot be &gt; 120 for age in years &lt; 6. If age and age units are not valued, RR cannot be &gt; 120.
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5005_RespiratoryRate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(../Age castable as xs:integer and ../AgeUnits castable as xs:integer and . castable as xs:integer) then ((../Age &gt;= 6 and ../AgeUnits='4') or ((../Age &lt; 6 or ../AgeUnits != '4') and (. &lt;= 99))) else (if(. castable as xs:integer) then(. &lt; 99) else(true()))">
			5005: Invalid, out of range. RR cannot be &gt; 99 and &lt;=120 for age in years &lt; 6. If age and age units are not valued, RR cannot be &gt; 99.
		</sch:assert>	
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5006_RespiratoryRate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			5006: Field cannot be Not Applicable
		</sch:assert>
		<sch:assert id="5007_RespiratoryRate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &gt; 5) else (true())">
			5007: The value is below 5
		</sch:assert>	

		<sch:assert id="5008_RespiratoryRate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt; 75) else (true())">
			5008: The value is above 75
		</sch:assert>			
	</sch:rule>
</sch:pattern>
  <sch:pattern id="RespiratoryAssistance">
	<sch:title>RespiratoryAssistance Assertions</sch:title>		
	<sch:rule id="RespiratoryAssistance_self_rules" context="RespiratoryAssistance">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5102_RespiratoryAssistance" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			5102:Field cannot be blank
		</sch:assert>	
		<sch:assert id="5103_RespiratoryAssistance" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../RespiratoryRate/@biu ='2') then(@biu='1') else(true())">
			5103:Element must be Not Applicable when Initial ED/Hospital Respiratory Rate is Not Known/Not Recorded
		</sch:assert>			
	</sch:rule>
</sch:pattern>
  <sch:pattern id="PulseOximetry">
	<sch:title>PulseOximetry Assertions</sch:title>	
	
	<sch:rule id="PulseOximetry_self_rules" context="PulseOximetry">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5202_PulseOximetry" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			5202: Field cannot be blank
		</sch:assert>		
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5205_PulseOximetry" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			5205: Field cannot be Not Applicable
		</sch:assert>
		<sch:assert id="5207_PulseOximetry" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &gt; 40) else (true())">
			5207: The value is below 40
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="SupplementalOxygen">
	<sch:title>SupplementalOxygen Assertions</sch:title>	
	
	<sch:rule id="SupplementalOxygen_self_rules" context="SupplementalOxygen">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5303_SupplementalOxygen" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			5303: Field cannot be blank
		</sch:assert>
		<sch:assert id="5304_SupplementalOxygen" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../PulseOximetry/@biu ='2') then(@biu='1') else(true())">
			5304: Element must be Not Applicable when Initial ED/Hospital Oxygen Saturation is Not Known/Not Recorded
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="GcsEye">
	<sch:title>GcsEye Assertions</sch:title>	
	
	<sch:rule id="GcsEye_self_rules" context="GcsEye">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5403_GcsEye" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			5403: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5404_GcsEye" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			5404: Field cannot be Not Applicable
		</sch:assert>
		<sch:assert id="5405_GcsEye" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../Gcs40Eye != '') then(@biu='2') else(true())">
			5405: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS 40 – Eye is reported
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="GcsVerbal">
	<sch:title>GcsVerbal Assertions</sch:title>	

	<sch:rule id="GcsVerbal_self_rules" context="GcsVerbal">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5503_GcsVerbal" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			5503: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5504_GcsVerbal" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			5504: Field cannot be Not Applicable
		</sch:assert>
		<sch:assert id="5505_GcsVerbal" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../Gcs40Verbal != '') then(@biu='2') else(true())">
			5505: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS 40 – Verbal is reported
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="GcsMotor">
	<sch:title>GcsMotor Assertions</sch:title>	
	
	<sch:rule id="GcsMotor_self_rules" context="GcsMotor">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5603_GcsMotor" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			5603: Field cannot be blank
		</sch:assert>	
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5604_GcsMotor" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			5604: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:assert id="5605_GcsMotor" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../Gcs40Motor != '') then(@biu='2') else(true())">
			5605: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS 40 - Motor is reported
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="TotalGcs">
	<sch:title>TotalGcs Assertions</sch:title>	
	
	<sch:rule id="TotalGcs_self_rules" context="TotalGcs">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5705_TotalGcs" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			5705: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5706_TotalGcs" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			5706: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:assert id="5703_TotalGcs" role="[WARNING]" diagnostics="ntdbDiagnostic" test="not (../GcsEye !='' and ../GcsVerbal != '' and ../GcsMotor != '') or (. = ../GcsEye + ../GcsVerbal + ../GcsMotor)">
			5703: Initial ED/Hospital GCS - Total does not equal the sum of Initial ED/Hospital GCS - Eye, Initial ED/Hospital GCS - Verbal, and Initial ED/Hospital GCS - Motor
		</sch:assert>

		<sch:assert id="5707_TotalGcs" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(../Gcs40Eye != '' or ../Gcs40Verbal != '' or ../Gcs40Motor != '') then(@biu='2') else(true())">
			5707: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS 40 – Eye, Initial ED/Hospital GCS 40 – Verbal, or Initial ED/Hospital GCS 40 – Motor are reported
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="GcsQualifier">
	<sch:title>GcsQualifier Assertions</sch:title>	

	<sch:rule id="GcsQualifier_self_rules" context="GcsQualifier">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5802_GcsQualifier" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			5802: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5803_GcsQualifier" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			5803: Field cannot be Not Applicable
		</sch:assert>	
		<sch:assert id="5804_GcsQualifier" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../../../Gcs40Eye != '' or ./../../../Gcs40Verbal != '' or ./../../../Gcs40Motor != '') then(every $element in ./../../item/GcsQualifier satisfies $element/@biu='2') else(true())">
			5804: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS 40 – Eye, Initial ED/Hospital GCS 40 – Verbal, or Initial ED/Hospital GCS 40 – Motor are reported
		</sch:assert>	
		<sch:assert id="5805_GcsQualifier" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu='2') then(every $element in ./../../item/GcsQualifier satisfies $element='') else(true())">
			5805: Element cannot be Not Known/Not Recorded along with any other valid value
		</sch:assert>		
	</sch:rule>
</sch:pattern>


<sch:pattern id="Gcs40Eye">
	<sch:title>Gcs40Eye Assertions</sch:title>	

	<sch:rule id="Gcs40Eye_self_rules" context="Gcs40Eye">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="15303_Gcs40Eye" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			15303: Field cannot be blank
		</sch:assert>

		<sch:assert id="15304_Gcs40Eye" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			15304: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:assert id="15306_Gcs40Eye" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../GcsEye !='') then(@biu='2') else(true())">
			15306: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS – Eye is reported.
		</sch:assert>

	</sch:rule>
</sch:pattern>


<sch:pattern id="Gcs40Verbal">
	<sch:title>Gcs40Motor Assertions</sch:title>	

	<sch:rule id="Gcs40Verbal_self_rules" context="Gcs40Verbal">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="15403_Gcs40Verbal" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			15403: Field cannot be blank
		</sch:assert>

		<sch:assert id="15404_Gcs40Verbal" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			15404: Field cannot be Not Applicable
		</sch:assert>

		<sch:assert id="15406_Gcs40Verbal" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../GcsVerbal !='') then(@biu='2') else(true())">
			15406: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS – Verbal is reported.
		</sch:assert>

	</sch:rule>
</sch:pattern>
<sch:pattern id="Gcs40Motor">
	<sch:title>Gcs40Motor Assertions</sch:title>	

	<sch:rule id="Gcs40Motor_self_rules" context="Gcs40Motor">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="15503_Gcs40Motor" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			15503: Field cannot be blank
		</sch:assert>

		<sch:assert id="15504_Gcs40Motor" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			15504: Field cannot be Not Applicable
		</sch:assert>

		<sch:assert id="15506_Gcs40Motor" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../GcsMotor !='') then(@biu='2') else(true())">
			15506: Element must be Not Known/Not Recorded when Initial ED/Hospital GCS – Motor is reported.
		</sch:assert>

	</sch:rule>
</sch:pattern>

  <sch:pattern id="Height">
	<sch:title>Height Assertions</sch:title>	

	<sch:rule id="Height_self_rules" context="Height">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8502_Height" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			8502: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8504_Height" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			8504: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:assert id="8503_Height" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:decimal) then(. &lt; 215) else (true())">
			8503: The value is above 215
		</sch:assert>
		

		<sch:assert id="8506_Height" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:decimal) then(. &gt; 50) else (true())">
			8506: The value is below 50
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="Weight">
	<sch:title>Weight Assertions</sch:title>	

	<sch:rule id="Weight_self_rules" context="Weight">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8602_Weight" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			8602: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8604_Weight" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			8604: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:assert id="8603_Weight" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:decimal) then(. &lt; 200) else (true())">
			8603: The value is above 200
		</sch:assert>	

		<sch:assert id="8606_Weight" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:decimal) then(. &gt; 3) else (true())">
			8606: The value is below 3
		</sch:assert>	
	</sch:rule>
</sch:pattern>
  <sch:pattern id="DrugScreen">
	<sch:title>DrugScreen Assertions</sch:title>	

	<sch:rule id="DrugScreen_self_rules" context="DrugScreen">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6012_DrugScreen" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			6012: Field cannot be blank
		</sch:assert>	
		<sch:assert id="6013_DrugScreen" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			6013: Field cannot be Not Applicable
		</sch:assert>
		<sch:assert id="6014_DrugScreen" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu='2') then(every $element in ./../../item/DrugScreen satisfies $element='') else(true())">
			6014: Element cannot be Not Known/Not Recorded along with any other valid value
		</sch:assert>			
	</sch:rule>
</sch:pattern>
  <sch:pattern id="AlcoholScreen">
	<sch:title>AlcoholScreen Assertions</sch:title>	

	<sch:rule id="AlcoholScreen" context="AlcoholScreen">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5912_AlcoholScreen" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			5912: Field cannot be blank
		</sch:assert>
		<sch:assert id="5913_AlcoholScreen" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			5913: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="AlcoholScreenResult">
	<sch:title>AlcoholScreenResult Assertions</sch:title>	

	<sch:rule id="AlcoholScreenResult" context="AlcoholScreenResult">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="5932_AlcoholScreenResult" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			5932: Field cannot be blank
		</sch:assert>
		<sch:assert id="5933_AlcoholScreenResult" role="[ERROR]" diagnostics="ntdbDiagnostic" test="../AlcoholScreen !='1' or not(@biu='1')">
			5933: Field cannot be Not Applicable when Alcohol Screen is 1 (Yes)
		</sch:assert>
		<sch:assert id="5936_AlcoholScreenResult" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:decimal) then(. &lt; 0.4) else (true())">
			5936: The value is above 0.4
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EdDischargeDisposition">
	<sch:title>EdDischargeDisposition Assertions</sch:title>	

	<sch:rule id="EdDischargeDisposition_self_rules" context="EdDischargeDisposition">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6102_EdDischargeDisposition" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			6102: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="6104_EdDischargeDisposition" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('2'))">
			6104: Field cannot be Not Known/Not Recorded
		</sch:assert>
		

		<sch:let name="ntdbElements" value=".,../HospitalDischargeOrdersWrittenDate"/>
		<sch:assert id="6106_EdDischargeDisposition" role="[ERROR]" diagnostics="ntdbDiagnostic" test="@biu=('1') or not(../HospitalDischargeOrdersWrittenDate[@biu]='1')">
			6106: Field cannot not be Not Applicable when Hospital Discharge Date is Not Applicable
		</sch:assert>
		

		<sch:let name="ntdbElements" value=".,../HospitalDischargeOrdersWrittenDate"/>
		<sch:assert id="6107_EdDischargeDisposition" role="[ERROR]" diagnostics="ntdbDiagnostic" test="@biu=('1') or not(../HospitalDischargeOrdersWrittenDate[@biu]='2')">
			6107: Field cannot not be Not Applicable when Hospital Discharge Date is Not Known/Not Recorded
		</sch:assert>
		
		<sch:let name="ntdbElements" value=".,../HospitalDischargeDisposition"/>
		<sch:assert id="6108_EdDischargeDisposition" role="[ERROR]" diagnostics="ntdbDiagnostic" test="@biu=('1') or not(../HospitalDischargeDisposition[@biu]='1')">
			6108: Field cannot not be Not Applicable when Hospital Discharge Disposition is Not Applicable
		</sch:assert>
		
		<sch:let name="ntdbElements" value=".,../HospitalDischargeDisposition"/>
		<sch:assert id="6109_EdDischargeDisposition" role="[ERROR]" diagnostics="ntdbDiagnostic" test="@biu=('1') or not(../HospitalDischargeDisposition[@biu]='2')">
			6109: Field cannot not be Not Applicable when Hospital Discharge Disposition is Not Known/Not Recorded
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="DeathInEd">
	<sch:title>DeathInEd Assertions</sch:title>	
	
	<sch:rule id="DeathInEd_self_rules" context="DeathInEd">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6202_DeathInEd" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			6202: Field cannot be blank
		</sch:assert>
				
		<sch:assert id="6207_DeathInEd" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			6207: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:let name="ntdbElements" value=".,../Sbp,../PulseRate,../GcsMotor"/>
		<sch:assert id="6208_DeathInEd" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(../Sbp castable as xs:integer and ../PulseRate castable as xs:integer and ../GcsMotor castable as xs:integer) then(not(../Sbp &gt; 0 or ../PulseRate &gt; 0 or ../GcsMotor &gt; 1) or not(. ='1')) else(true())">
			6208: Field is 1 (Arrived with NO signs of life) when Initial ED/Hospital SBP &gt; 0, Pulse &gt; 0, OR GCS Motor &gt; 1. Please verify.
		</sch:assert>
		
		<sch:let name="ntdbElements" value=".,../Sbp,../PulseRate,../GcsMotor"/>
		<sch:assert id="6209_DeathInEd" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(../Sbp castable as xs:integer and ../PulseRate castable as xs:integer and ../GcsMotor castable as xs:integer) then(not(../Sbp = 0 and ../PulseRate = 0 and ../GcsMotor = 1)  or not(. ='2')) else(true())">
			6209: Field is 2 (Arrived with signs of life) when Initial ED/Hospital SBP = 0, Pulse = 0, AND GCS Motor = 1. Please verify.
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EdDischargeOrdersWrittenDate">
	<sch:title>EdDischargeOrdersWrittenDate Assertions</sch:title>	

	<sch:rule id="EdDischargeOrdersWrittenDate_self_rules" context="EdDischargeOrdersWrittenDate">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6303_EdDischargeOrdersWrittenDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			6303: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6304_EdDischargeOrdersWrittenDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsNotifyDate)">
			6304: ED Discharge Date is earlier than EMS Dispatch Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6305_EdDischargeOrdersWrittenDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsArrivalDate)">
			6305: ED Discharge Date is earlier than EMS Unit Arrival on Scene Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6306_EdDischargeOrdersWrittenDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsLeftDate)">
			6306: ED Discharge Date is earlier than EMS Unit Scene Departure Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6307_EdDischargeOrdersWrittenDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../HospitalArrivalDate)">
			6307: ED Discharge Date is earlier than ED/Hospital Arrival Date
		</sch:assert>		
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6308_EdDischargeOrdersWrittenDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(../HospitalDischargeOrdersWrittenDate, .)">
			6308: ED Discharge Date is later than Hospital Discharge Date
		</sch:assert>		
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6309_EdDischargeOrdersWrittenDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../DateOfBirth)">
			6309: ED/Hospital Arrival Date is earlier than Date of Birth
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/> 
		<sch:assert id="6310_EdDischargeOrdersWrittenDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test=". = '' or ../HospitalArrivalDate = '' or (fct:durationParse(../HospitalArrivalDate, ., '2') &lt; 365)">
			6310: ED Discharge Date minus ED/Hospital Arrival Date is greater than 365 days
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EdDischargeOrdersWrittenTime">
	<sch:title>EdDischargeOrdersWrittenTime Assertions</sch:title>	
	
	<sch:rule id="EdDischargeOrdersWrittenTime_self_rules" context="EdDischargeOrdersWrittenTime">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6403_EdDischargeOrdersWrittenTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			6403: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6404_EdDischargeOrdersWrittenTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)">
			6404: ED Discharge Time is earlier than EMS Dispatch Time
		</sch:assert>	
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6405_EdDischargeOrdersWrittenTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)">
			6405: ED Discharge Time is earlier than EMS Unit Arrival on Scene Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6406_EdDischargeOrdersWrittenTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../EmsLeftDate) or fct:notLessThanTime(., ../EmsLeftTime)">
			6406: ED Discharge Time is earlier than EMS Unit Scene Departure Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6407_EdDischargeOrdersWrittenTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../HospitalArrivalDate) or fct:notLessThanTime(., ../HospitalArrivalTime)">
			6407: ED Discharge Time is earlier than ED/Hospital Arrival Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6408_EdDischargeOrdersWrittenTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../EdDischargeOrdersWrittenDate, ../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(../HospitalDischargeOrdersWrittenTime, .)">
			6408: ED Discharge Time is later than Hospital Discharge Time
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="HighestTraumaActivation">
	<sch:title>HighestTraumaActivation Assertions</sch:title>	
	
	<sch:rule id="HighestTraumaActivation_self_rules" context="HighestTraumaActivation">
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="14202_HighestTraumaActivation" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			14202: Element cannot be blank
		</sch:assert>		
		
	</sch:rule>
</sch:pattern>
<sch:pattern id="TraumaSurgeonHighestActivationArrivalTime">
	<sch:title>TraumaSurgeonHighestActivationArrivalTime Assertions</sch:title>	
	
	<sch:rule id="TraumaSurgeonHighestActivationArrivalTime_self_rules" context="TraumaSurgeonHighestActivationArrivalTime">

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="14403_TraumaSurgeonHighestActivationArrivalTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			14403: Element cannot be blank
		</sch:assert>

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="14404_TraumaSurgeonHighestActivationArrivalTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../IncidentTime)">
			14404: Trauma Surgeon Arrival Time is earlier than Injury Incident Time
		</sch:assert>

	</sch:rule>
</sch:pattern>

<sch:pattern id="Dbp">
	<sch:title>Dbp Assertions</sch:title>	
	
	<sch:rule id="Dbp_self_rules" context="Dbp">

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="14502_Dbp" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			14502: Element cannot be blank
		</sch:assert>

	</sch:rule>
</sch:pattern>

<sch:pattern id="TraumaTeamInvolvement">
	<sch:title>TraumaTeamInvolvement Assertions</sch:title>	
	
	<sch:rule id="Dbp_self_rules" context="TraumaTeamInvolvement">

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="14602_TraumaTeamInvolvement" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			14602: Element cannot be blank
		</sch:assert>
	
	</sch:rule>
</sch:pattern>
  
  <sch:pattern id="HospitalProcedureIcd10">
	<sch:title>HospitalProcedureIcd10 Assertions</sch:title>	
	
	<sch:rule id="HospitalProcedureIcd10_self_rules" context="HospitalProcedureIcd10">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8803_HospitalProcedureIcd10" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			8803: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="8804_HospitalProcedureIcd10" role="[WARNING]" diagnostics="ntdbDiagnostic" test="not(@biu='1') or (every $element in (./following-sibling::*) satisfies ($element=''))">
			8804: Field should not be Not Applicable unless patient had no procedures performed
		</sch:assert>
	</sch:rule>
	
</sch:pattern>
  <sch:pattern id="HospitalProcedureStartDate">
	<sch:title>HospitalProcedureStartDate Assertions</sch:title>	

	<sch:rule id="HospitalProcedureStartDate_self_rules" context="HospitalProcedureStartDate">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6609_HospitalProcedureStartDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			6609: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6603_HospitalProcedureStartDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ./../../../EmsNotifyDate)">
			6603: Hospital Procedure Start Date is earlier than EMS Dispatch Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="., ./../../../EmsArrivalDate"/>
		<sch:assert id="6604_HospitalProcedureStartDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ./../../../EmsArrivalDate)">
			6604: Hospital Procedure Start Date is earlier than EMS Unit Arrival on Scene Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value=".,./../../../EmsLeftDate"/>
		<sch:assert id="6605_HospitalProcedureStartDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ./../../../EmsLeftDate)">
			6605: Hospital Procedure Start Date is earlier than EMS Unit Scene Departure Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value=".,./../../../HospitalArrivalDate"/>
		<sch:assert id="6606_HospitalProcedureStartDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ./../../../HospitalArrivalDate)">
			6606: Hospital Procedure Start Date is earlier than ED/Hospital Arrival Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6607_HospitalProcedureStartDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(./../../../HospitalDischargeOrdersWrittenDate, .)">
			6607: Hospital Procedure Start Date is later than Hospital Discharge Date
		</sch:assert>
		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="HospitalProcedureStartTime">
	<sch:title>HospitalProcedureStartDate Assertions</sch:title>	
	
	<sch:rule id="HospitalProcedureStartTime_self_rules" context="HospitalProcedureStartTime">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6708_HospitalProcedureStartTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			6708: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6703_HospitalProcedureStartTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../HospitalProcedureStartDate, ./../../../EmsNotifyDate) or fct:notLessThanTime(., ./../../../EmsNotifyTime)">
			6703: Hospital Procedure Start Time is earlier than EMS Dispatch Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6704_HospitalProcedureStartTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../HospitalProcedureStartDate, ./../../../EmsArrivalDate) or fct:notLessThanTime(., ./../../../EmsArrivalTime)">
			6704: Hospital Procedure Start Time is earlier than EMS Unit Arrival on Scene Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6705_HospitalProcedureStartTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalProcedureStartDate, ./../../../EmsLeftDate) or fct:notLessThanTime(., ./../../../EmsLeftTime)">
			6705: Hospital Procedure Start Time is earlier than EMS Unit Scene Departure Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6706_HospitalProcedureStartTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalProcedureStartDate, ./../../../HospitalArrivalDate) or fct:notLessThanTime(., ./../../../HospitalArrivalTime)">
			6706: Hospital Procedure Start Time is earlier than ED/Hospital Arrival Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6707_HospitalProcedureStartTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalProcedureStartDate, ./../../../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../../../HospitalDischargeOrdersWrittenTime, .)">
			6707: Hospital Procedure Start Time is later than Hospital Discharge Time
		</sch:assert>
	</sch:rule>
</sch:pattern>
  
  
  <sch:pattern id="ComorbidCondition">
	<sch:title>ComorbidCondition Assertions</sch:title>	

	<sch:rule id="ComorbidCondition_self_rules" context="ComorbidCondition">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="6802_ComorbidCondition" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			6802: Field cannot be blank
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="DiagnosisIcd10">
	<sch:title>DiagnosisIcd10 Assertions</sch:title>	
	
	<sch:rule id="DiagnosisIcd10_self_rules" context="DiagnosisIcd10">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8702_DiagnosisIcd10" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			8702: Field cannot be blank
		</sch:assert>
		
	</sch:rule>
	
	<sch:rule id="DiagnosisIcd10_global_rule" context="TxTdsRecord">
		<sch:let name="ntdbElements" value="DiagnosesIcd10/item/DiagnosisIcd10"/>
		<sch:assert id="8703_DiagnosisIcd10" role="[ERROR]" diagnostics="ntdbDiagnostic" test="some $element in (DiagnosesIcd10/item/DiagnosisIcd10) satisfies ($element/@biu = '1' or $element != '')">
			8703: At least one diagnosis must be provided and meet inclusion criteria.
		</sch:assert>
	</sch:rule>
</sch:pattern>
  
  
  <sch:pattern id="AisPredot">
	<sch:title>AisPredot Assertions</sch:title>	

	<sch:rule id="AisPredot_self_rules" context="AisPredot">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7007_AisPredot" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			7007: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7008_AisPredot" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			7008: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="AisSeverity">
	<sch:title>AisSeverity Assertions</sch:title>	

	<sch:rule id="AisSeverity_self_rules" context="AisSeverity">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7103_AisSeverity" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			7103: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7104_AisSeverity" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			7104: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="AisVersion">
	<sch:title>AisVersion Assertions</sch:title>	

	<sch:rule id="AisVersion_self_rules" context="AisVersion">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7302_AisVersion" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			7302: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7303_AisVersion" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			7303: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  
  
  <sch:pattern id="TotalIcuLos">
	<sch:title>TotalIcuLos Assertions</sch:title>	

	<sch:rule id="TotalIcuLos_self_rules" context="TotalIcuLos">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7502_TotalIcuLos" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			7502: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7503_TotalIcuLos" role="[WARNING]" diagnostics="ntdbDiagnostic" test="../HospitalArrivalDate ='' or ../HospitalDischargeOrdersWrittenDate ='' or . = '' or . &lt;= fct:durationParse(../HospitalArrivalDate, ../HospitalDischargeOrdersWrittenDate, '2')">
			7503: Total ICU Length of Stay is greater than the difference between ED/Hospital Arrival Date and Hospital Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7504_TotalIcuLos" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt; 60) else(true())">
			7504: Value is greater than 60, please verify this is correct
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="TotalVentDays">
	<sch:title>TotalVentDays Assertions</sch:title>	

	<sch:rule id="TotalVentDays_self_rules" context="TotalVentDays">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7502_TotalVentDays" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			7602: Field cannot be blank
		</sch:assert>
		
		<sch:let name="hospitalArrive" value="fct:parseDate(../HospitalArrivalDate)"/>
		<sch:let name="hospitalDischarge" value="fct:parseDate(../HospitalDischargeOrdersWrittenDate)"/>
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7603_TotalVentDays" role="[WARNING]" diagnostics="ntdbDiagnostic" test="../HospitalArrivalDate ='' or ../HospitalDischargeOrdersWrittenDate ='' or .='' or . &lt;= fct:durationParse(../HospitalArrivalDate, ../HospitalDischargeOrdersWrittenDate, '2')">
			7603: Total Ventilator Days should not be greater than the difference between ED/Hospital Arrival Date and Hospital Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7604_TotalVentDays" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt; 60) else(true())">
			7604: Value is greater than 60, please verify this is correct
		</sch:assert>
	</sch:rule>
</sch:pattern>
<sch:pattern id="HospitalDischargeOrdersWrittenDate">
	<sch:title>HospitalDischargeOrdersWrittenDate Assertions</sch:title>	

	<sch:rule id="HospitalDischargeOrdersWrittenDate_self_rules" context="HospitalDischargeOrdersWrittenDate">
	<sch:let name="ntdbElements" value="."/>
	<sch:assert id="7703_HospitalDischargeOrdersWrittenDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
		7703: Field cannot be blank
	</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7704_HospitalDischargeOrdersWrittenDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsNotifyDate)">
			7704: Hospital Discharge Date is earlier than EMS Dispatch Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7705_HospitalDischargeOrdersWrittenDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsArrivalDate)">
			7705: Hospital Discharge Date is earlier than EMS Unit Arrival on Scene Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7706_HospitalDischargeOrdersWrittenDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EmsLeftDate)">
			7706: Hospital Discharge Date is earlier than EMS Unit Scene Departure Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7707_HospitalDischargeOrdersWrittenDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../HospitalArrivalDate)">
			7707: Hospital Discharge Date is earlier than ED/Hospital Arrival Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7708_HospitalDischargeOrdersWrittenDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../EdDischargeOrdersWrittenDate)">
			7708: Hospital Discharge Date is earlier than ED Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7709_HospitalDischargeOrdersWrittenDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ../DateOfBirth)">
			7709: Hospital Discharge Date is earlier than Date of Birth
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7710_HospitalDischargeOrdersWrittenDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test=". = '' or ../IncidentDate = '' or (fct:durationParse(../IncidentDate, ., '2') &lt;= 365)">
			7710: Hospital Discharge Date minus Injury Incident Date is greater than 365 days, please verify this is correct
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7711_HospitalDischargeOrdersWrittenDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test=". = '' or ../HospitalArrivalDate = '' or (fct:durationParse(../HospitalArrivalDate, ., '2') &lt;= 365)">
			7711: Hospital Discharge Date minus ED/Hospital Arrival Date is greater than 365 days, please verify this is correct
		</sch:assert>
		<sch:let name="ntdbElements" value=".,../EdDischargeDisposition "/>
		<sch:assert id="7712_HospitalDischargeDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(../EdDischargeDisposition=('4','5', '6', '9', '10', '11')) or @biu='1'">
			7712: Field must be Not Applicable when ED Discharge Disposition = 4,5,6,9,10, or 11
		</sch:assert>				
	</sch:rule>
</sch:pattern>
  <sch:pattern id="HospitalDischargeOrdersWrittenTime">
	<sch:title>HospitalDischargeOrdersWrittenDate Assertions</sch:title>	

<sch:rule id="HospitalDischargeOrdersWrittenTime_self_rules" context="HospitalDischargeOrdersWrittenTime">
<sch:let name="ntdbElements" value="."/>
<sch:assert id="7803_HospitalDischargeOrdersWrittenTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
		7803: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7804_HospitalDischargeOrdersWrittenTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EmsNotifyDate) or fct:notLessThanTime(., ../EmsNotifyTime)">
			7804: Hospital Discharge Time is earlier than EMS Dispatch Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7805_HospitalDischargeOrdersWrittenTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EmsArrivalDate) or fct:notLessThanTime(., ../EmsArrivalTime)">
			7805: Hospital Discharge Time is earlier than EMS Unit Arrival on Scene Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7806_IncidentTime" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EmsLeftDate) or fct:notLessThanTime(., ../EmsLeftTime)">
			7806: Hospital Discharge Time is earlier than EMS Unit Scene Departure Time
		</sch:assert>
			
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7807_HospitalDischargeOrdersWrittenTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../HospitalArrivalDate) or fct:notLessThanTime(., ../HospitalArrivalTime)">
			7807: Hospital Discharge Time is earlier than ED/Hospital Arrival Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7808_IncidentTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(../HospitalDischargeOrdersWrittenDate, ../EdDischargeOrdersWrittenDate) or fct:notLessThanTime(., ../EdDischargeOrdersWrittenTime)">
			7808: Hospital Discharge Time is earlier than ED Discharge Time
		</sch:assert>		
	
		<sch:let name="ntdbElements" value=".,../EdDischargeDisposition "/>
		<sch:assert id="7809_HospitalPhysicalDischargeTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(../EdDischargeDisposition=('4','5' ,'6', '9', '10', '11')) or @biu='1'">
			7809: Field must be Not Applicable when ED Discharge Disposition = 4,5,6,9,10, or 11
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="HospitalDischargeDisposition">
	<sch:title>HospitalDischargeDisposition Assertions</sch:title>	

	<sch:rule id="HospitalDischargeDisposition_self_rules" context="HospitalDischargeDisposition">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="7902_HospitalDischargeDisposition" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			7902: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value=".,../EdDischargeDisposition "/>
		<sch:assert id="7907_TotalVentDays" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(../EdDischargeDisposition=('4', '6', '9', '10', '11')) or .='' or @biu='1'">
			7907: Field must be Not Applicable when ED Discharge Disposition = 4,6,9,10, or 11
		</sch:assert>
		
		<sch:let name="ntdbElements" value=".,../EdDischargeDisposition "/>
		<sch:assert id="7908_HospitalDischargeDisposition" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1') or ../EdDischargeDisposition=('4', '5', '6', '9', '10', '11')">
			7908: Element cannot be Not Applicable if ED Discharge Disposition is not 4, 5, 6, 9, 10,or 11
		</sch:assert>
		
		<sch:let name="ntdbElements" value=".,../EdDischargeDisposition "/>
		<sch:assert id="7909_HospitalDischargeDisposition" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='2') or (../HospitalArrivalDate = '' and ../HospitalDischargeOrdersWrittenDate = '')">
			7909: Field cannot be Not Known/Not Recorded when Hospital Arrival Date and Hospital Discharge Date are not: (1) blank, (2) Not Applicable, or (3) Not Known/Not Recorded
		</sch:assert>
	</sch:rule>
</sch:pattern>
  
  
  <sch:pattern id="PrimaryMethodPayment">
	<sch:title>PrimaryMethodPayment Assertions</sch:title>	

	<sch:rule id="PrimaryMethodPayment_self_rules" context="PrimaryMethodPayment">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8002_PrimaryMethodPayment" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			8002: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8003_PrimaryMethodPayment" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu='1')">
			8003: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>	
</sch:pattern>
  
  
  <sch:pattern id="HospitalComplication">
	<sch:title>HospitalComplication Assertions</sch:title>	

	<sch:rule id="HospitalComplication_self_rules" context="HospitalComplication">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8102_HospitalComplication" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			8102: Field cannot be blank
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="8103_HospitalComplication" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. = '35') then(../../TotalVentDays != '' or ../../TotalVentDays[@biu] != '1') else (true())">
			8103: Hospital Complications include Ventilator Associated Pneumonia although Total Ventilator Days is Not Applicable. Please verify.
		</sch:assert>
	</sch:rule>
</sch:pattern>
  
  
  <sch:pattern id="NationalProviderIdentifier">
	<sch:title>NationalProviderIdentifier Assertions</sch:title>	

	<sch:rule id="NationalProviderIdentifier" context="NationalProviderIdentifier">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="9802_NationalProviderIdentifier" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			9802: Field cannot be blank
		</sch:assert>
	</sch:rule>
</sch:pattern>
  
  
  <sch:pattern id="TbiHighestTotalGcs">
	<sch:title>TbiHighestTotalGcs Assertions</sch:title>	

	<sch:rule id="TbiHighestTotalGcs_self_rules" context="TbiHighestTotalGcs">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="10002_TbiHighestTotalGcs" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			10002: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="10003_TbiHighestTotalGcs" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer and ./../TbiGcsMotor castable as xs:integer) then(xs:integer(.) &gt;= xs:integer(./../TbiGcsMotor)) else(true())">
			10003: Highest GCS Total is less than GCS Motor Component of Highest GCS Total
		</sch:assert>
		
		<sch:let name="headInjury" value="if(./../AisCodes/item/AisPredot) then(some $element in (./../AisCodes/item/AisPredot) satisfies substring($element, 1, 1) = '1') else(false())"/>
		<sch:let name="nextDay" value="current-dateTime() + xs:dayTimeDuration('PT24H')"/>
		<sch:let name="ed_discharge_date" value="./../EdDischargePhysicalDate"/>
		<sch:let name="hospital_discharge_date" value="./../HospitalPhysicalDischargeDate"/>
		
		<sch:assert id="10006_TbiHighestTotalGcs" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(../TbiGcs40Motor != '') then(@biu='2') else(true())">
			10006: Element must be Not Known/Not Recorded when Highest GCS 40 - Motor is reported.
		</sch:assert>

	</sch:rule>
</sch:pattern>
  <sch:pattern id="TbiGcsMotor">
	<sch:title>TbiGcsMotor Assertions</sch:title>	

	<sch:rule id="TbiGcsMotor_self_rules" context="TbiGcsMotor">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="10102_TbiGcsMotor" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			10102: Field cannot be blank
		</sch:assert>
		<sch:assert id="10106_TbiGcsMotor" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(../TbiGcs40Motor != '') then(@biu='2') else(true())">
			10106: Field must be Not Known/Not Recorded when Highest GCS 40 - Motor is reported
		</sch:assert>
		
		<sch:let name="headInjury" value="if(./../AisCodes/item/AisPredot) then(some $element in (./../AisCodes/item/AisPredot) satisfies substring($element, 1, 1) = '1') else(false())"/>
		<sch:let name="nextDay" value="current-dateTime() + xs:dayTimeDuration('PT24H')"/>
		<sch:let name="ed_discharge_date" value="./../EdDischargePhysicalDate"/>
		<sch:let name="hospital_discharge_date" value="./../HospitalPhysicalDischargeDate"/>


	</sch:rule>

</sch:pattern>
  <sch:pattern id="TbiGcsQualifier">
	<sch:title>TbiGcsQualifier Assertions</sch:title>	

	<sch:rule id="TbiGcsQualifier_self_rules" context="TbiGcsQualifier">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="10202_TbiGcsQualifier" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			10202: Field cannot be blank
		</sch:assert>
		<sch:assert id="10206_TbiGcsQualifier" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../../../TbiGcs40Motor != '') then(every $element in ./../../item/TbiGcsQualifier satisfies $element/@biu = '2') else(true())">
			10206: Element must be Not Known/Not Recorded when Highest GCS 40 - Motor is reported
		</sch:assert>	
		<sch:assert id="10207_TbiGcsQualifier" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1','2')) then(every $element in ./../../item/TbiGcsQualifier satisfies $element='') else(true())">
			10207: Element cannot be Not Applicable or Not Known/Not Recorded along with any other valid value
		</sch:assert>	

		<sch:let name="headInjury" value="if(./../../../AisCodes/item/AisPredot) then(some $element in (./../../../AisCodes/item/AisPredot) satisfies substring($element, 1, 1) = '1') else(false())"/>
		<sch:let name="nextDay" value="current-dateTime() + xs:dayTimeDuration('PT24H')"/>		
		<sch:let name="ed_discharge_date" value="./../../../EdDischargePhysicalDate"/>
		<sch:let name="hospital_discharge_date" value="./../../../HospitalPhysicalDischargeDate"/>


	</sch:rule>
</sch:pattern><sch:pattern id="TbiGcs40Motor">
	<sch:title>TbiGcs40Motor Assertions</sch:title>	

	<sch:rule id="TbiGcs40Motor" context="TbiGcs40Motor">
		<sch:let name="ntdbElements" value="."/>	
		<sch:let name="headInjury" value="if(./../AisCodes/item/AisPredot) then(some $element in (./../AisCodes/item/AisPredot) satisfies substring($element, 1, 1) = '1') else(false())"/>
		<sch:let name="nextDay" value="current-dateTime() + xs:dayTimeDuration('PT24H')"/>
		<sch:let name="ed_discharge_date" value="./../EdDischargePhysicalDate"/>
		<sch:let name="hospital_discharge_date" value="./../HospitalPhysicalDischargeDate"/>

		<sch:assert id="20602_TbiGcs40Motor" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			20602: Field cannot be blank
		</sch:assert>

		<sch:assert id="20606_TbiGcs40Motor" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(../TbiGcsMotor != '') then(@biu='2') else(true())">
			20606: Element must be Not Known/Not Recorded when Highest GCS - Motor is reported
		</sch:assert>	


	</sch:rule>
</sch:pattern>
  <sch:pattern id="TbiPupillaryResponse">
	<sch:title>TbiPupillaryResponse Assertions</sch:title>	

	<sch:rule id="TbiPupillaryResponse_self_rules" context="TbiPupillaryResponse">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="13602_TbiPupillaryResponse" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			13602: Field cannot be blank
		</sch:assert>

	</sch:rule>
</sch:pattern>
  <sch:pattern id="TbiMidlineShift">
	<sch:title>TbiMidlineShift Assertions</sch:title>	

	<sch:rule id="TbiMidlineShift_self_rules" context="TbiMidlineShift">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="13702_TbiMidlineShift" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			13702: Field cannot be blank
		</sch:assert>

	</sch:rule>
</sch:pattern>
  <sch:pattern id="TbiCerebralMonitor">
	<sch:title>TbiCerebralMonitor Assertions</sch:title>	

	<sch:rule id="TbiCerebralMonitor_self_rules" context="TbiCerebralMonitor">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="10302_TbiCerebralMonitor" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			10302: Field cannot be blank
		</sch:assert>
		<sch:assert id="10306_TbiCerebralMonitor" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1','2')) then(every $element in ./../../item/TbiCerebralMonitor satisfies $element='') else(true())">
			10306: Element cannot be “Not Applicable” or “Not Known/Not Recorded” along with any other valid value
		</sch:assert>

	</sch:rule>
</sch:pattern>
  <sch:pattern id="TbiCerebralMonitorDate">
	<sch:title>TbiCerebralMonitorDate Assertions</sch:title>	

	<sch:rule id="TbiCerebralMonitorDate_self_rules" context="TbiCerebralMonitorDate">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="10402_TbiCerebralMonitorDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			10402: Field cannot be blank
		</sch:assert>

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10404_TbiCerebralMonitorDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu = '1') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor = '5' or ./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())">
			10404: Field cannot be Not Applicable when Cerebral Monitor is not: (1) blank, (2) Not Applicable, (3) Not Known/Not Recorded, or (4) None
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10405_TbiCerebralMonitorDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(@biu = '2') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())">
			10405: Field should not be Not Known/Not Recorded when Cerebral Monitor is not: (1) blank, (2) Not Applicable, or (3) Not Known/Not Recorded
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10407_TbiCerebralMonitorDate" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ./../HospitalArrivalDate)">
			10407: Cerebral Monitor Date should not be earlier than ED/Hospital Arrival Date unless placed at referring facility and used for monitoring
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10408_TbiCerebralMonitorDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
			10408: Cerebral Monitor Date should not be later than Hospital Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10409_TbiCerebralMonitorDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../TbiCerebralMonitor = '5' or ./../TbiCerebralMonitor/@biu = '1') then(@biu = '1') else(true()) ">
			10409: Field should be Not Applicable when Cerebral Monitor is Not Applicable or None
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="TbiCerebralMonitorTime">
	<sch:title>TbiCerebralMonitorTime Assertions</sch:title>	

	<sch:rule id="TbiCerebralMonitorTime_self_rules" context="TbiCerebralMonitorTime">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="10503_TbiCerebralMonitor" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			10503: Field cannot be blank
		</sch:assert>

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10504_TbiCerebralMonitorTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu = '1') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor = '5' or ./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())">
			10504: Field cannot be Not Applicable when Cerebral Monitor is not "Not Applicable" or "Not Known/Not Recorded" or "None"
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10505_TbiCerebralMonitor" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(@biu = '2') then(./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = ('1', '2')) else(true())">
			10505: Field should not be Not Known/Not Recorded when Cerebral Monitor is not "Not Applicable" or "Not Known/Not Recorded"
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10506_TbiCerebralMonitor" role="[WARNING]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../TbiCerebralMonitorDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)">
			10506: Cerebral Monitor Time should not be earlier than ED/Hospital Arrival Time unless placed at referring facility and used for monitoring
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10507_TbiCerebralMonitor" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../TbiCerebralMonitorDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
			10507: Cerebral Monitor Time should not be later than Hospital Discharge Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10508_TbiCerebralMonitor" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../TbiCerebralMonitors/item/TbiCerebralMonitor = '5' or ./../TbiCerebralMonitors/item/TbiCerebralMonitor/@biu = '1') then(@biu = '1') else(true()) ">
			10508: Field should be Not Applicable when Cerebral Monitor is Not Applicable or None
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="VteProphylaxisType">
	<sch:title>VteProphylaxisType Assertions</sch:title>	

	<sch:rule id="VteProphylaxisType_self_rules" context="VteProphylaxisType">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="10602_VteProphylaxisType" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			10602: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="10603_VteProphylaxisType" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			10603: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="VteProphylaxisDate">
	<sch:title>VteProphylaxisDate Assertions</sch:title>	

	<sch:rule id="VteProphylaxisDate_self_rules" context="VteProphylaxisDate">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="10703_VteProphylaxisDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			10703: Field cannot be blank
		</sch:assert>

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10705_VteProphylaxisDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu = '1') then(./../VteProphylaxisType = '5' or ./../VteProphylaxisType/@biu = ('1', '2')) else(true())">
			10705: Field cannot be Not Applicable when VTE Prophylaxis is not "Not Applicable" or "Not Known/Not Recorded" or "None"
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10706_VteProphylaxisDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ./../HospitalArrivalDate)">
			10706: VTE Prophylaxis Date is earlier than ED/Hospital Arrival Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10707_VteProphylaxisDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
			10707: VTE Prophylaxis Date is later than Hospital Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10708_VteProphylaxisDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../VteProphylaxisType = '5') then(@biu = '1') else(true()) ">
			10708: Field should be Not Applicable when VTE Prophylaxis is 'None'
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="VteProphylaxisTime">
	<sch:title>VteProphylaxisTime Assertions</sch:title>	

	<sch:rule id="VteProphylaxisTime_self_rules" context="VteProphylaxisTime">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="10803_VteProphylaxisTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			10803: Field cannot be blank
		</sch:assert>

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10805_VteProphylaxisTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu = '1') then(./../VteProphylaxisType = '5' or ./../VteProphylaxisType/@biu = ('1', '2')) else(true())">
			10805: Field cannot be Not Applicable when Cerebral Monitor is not "Not Applicable" or "Not Known/Not Recorded" or "None"
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10806_VteProphylaxisTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../VteProphylaxisDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)">
			10806: VTE Prophylaxis Time is earlier than ED/Hospital Arrival Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10807_VteProphylaxisTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../VteProphylaxisDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
			10807: VTE Prophylaxis Time is later than Hospital Discharge Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="10808_VteProphylaxisTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../VteProphylaxisType = '5') then(@biu = '1') else(true()) ">
			10808: Field should be Not Applicable when VTE Prophylaxis is 'None'
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="TransfusionBlood4Hours">
	<sch:title>TransfusionBlood4Hours Assertions</sch:title>	
	
	<sch:rule id="TransfusionBlood4Hours_self_rules" context="TransfusionBlood4Hours">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="21802_TransfusionBlood4Hours" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			21802: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="21803_TransfusionBlood4Hours" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			21803: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:assert id="21804_TransfusionBlood4Hours" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())">
			21804: Value exceeds 40,000 for CCs
		</sch:assert>
	</sch:rule>
</sch:pattern>
<sch:pattern id="WholeBlood4Hours">
	<sch:title>WholeBlood4Hours Assertions</sch:title>	
	
	<sch:rule id="WholeBlood4Hours_self_rules" context="WholeBlood4Hours">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="21102_WholeBlood4Hours" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			21102: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="21103_WholeBlood4Hours" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			21103: Field cannot be Not Applicable
		</sch:assert>
		
		<sch:assert id="21104_WholeBlood4Hours" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())">
			21104: Value exceeds 40,000 for CCs
		</sch:assert>
	</sch:rule>
</sch:pattern>
  
  <sch:pattern id="TransfusionPlasma4Hours">
	<sch:title>TransfusionPlasma4Hours Assertions</sch:title>	
	
	<sch:rule id="TransfusionPlasma4Hours_self_rules" context="TransfusionPlasma4Hours">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="21202_TransfusionPlasma4Hours" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			21202: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="11104_TransfusionPlasma4Hours" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())">
			21204: Value exceeds 40,000 for CCs
		</sch:assert>
		
		<sch:assert id="21208_TransfusionPlasma4Hours" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			21208: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="TransfusionPlatelets4Hours">
	<sch:title>TransfusionPlatelets4Hours Assertions</sch:title>	

	<sch:rule id="TransfusionPlatelets4Hours_self_rules" context="TransfusionPlatelets4Hours">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="21302_TransfusionPlatelets4Hours" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			21302: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="21304_TransfusionPlatelets4Hours" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())">
			21304: Value exceeds 40,000 for CCs
		</sch:assert>
		
		<sch:assert id="21308_TransfusionPlasma4Hours" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			21308: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="Cryoprecipitate4Hours">
	<sch:title>Cryoprecipitate4Hours Assertions</sch:title>	

	<sch:rule id="Cryoprecipitate4Hours_self_rules" context="Cryoprecipitate4Hours">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="21402_Cryoprecipitate4Hours" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			21402: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="11304_Cryoprecipitate4Hours" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt;= 40000) else(true())">
			21404: Value exceeds 40,000 for CCs
		</sch:assert>
		
		<sch:assert id="21408_Cryoprecipitate4Hours" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			21408: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="LowestSbp">
	<sch:title>LowestSbp Assertions</sch:title>	

	<sch:rule id="LowestSbp_self_rules" context="LowestSbp">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="10902_LowestSbp" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			10902: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="10903_LowestSbp" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &lt;= 220) else(true())">
			10903: The value is above 220
		</sch:assert>
		
		<sch:assert id="10905_LowestSbp" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours &gt; 0) or (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours &gt; 0)) then(not(@biu = '1')) else(true()) ">
			10905: Element cannot be Not Applicable when Packed Red Blood Cells or Whole Blood is greater than 0
		</sch:assert>
		
		<sch:assert id="10906_LowestSbp" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours = 0) and (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours = 0)) then(@biu = '1') else(true()) ">
			10906: Element must be Not Applicable when Packed Red Blood Cells and Whole Blood are 0
		</sch:assert>
		
		<sch:assert id="10907_LowestSbp" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../TransfusionBlood4Hours/@biu = '2' and ./../WholeBlood4Hours/@biu = '2') then(@biu = '2') else(true()) ">
			10907: Element must be Not Known/Not Recorded when Packed Red Blood Cells and Whole Blood are Not Known/Not Recorded
		</sch:assert>
		
		<sch:assert id="10909_LowestSbp" role="[WARNING]" diagnostics="ntdbDiagnostic" test="if(. castable as xs:integer) then(. &gt;= 30) else(true())">
			10909: Warning: SBP value below 30
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="Angiography">
	<sch:title>Angiography Assertions</sch:title>	

	<sch:rule id="Angiography_self_rules" context="Angiography">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="11702_Angiography" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			11702: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="11703_Angiography" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours &gt; 0) or (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours &gt; 0)) then(not(@biu = '1')) else(true()) ">
			11703: Element cannot be Not Applicable when Packed Red Blood Cells or Whole Blood is greater than 0
		</sch:assert>
		
		<sch:assert id="11704_Angiography" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours = 0) and (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours = 0)) then(@biu = '1') else(true()) ">
			11704: Element must be Not Applicable when Packed Red Blood Cells and Whole Blood are 0
		</sch:assert>
		
		<sch:assert id="11705_Angiography" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../TransfusionBlood4Hours/@biu = '2' and ./../WholeBlood4Hours/@biu = '2') then(@biu = '2') else(true()) ">
			11705: Element must be Not Known/Not Recorded when Packed Red Blood Cells and Whole Blood are “Not Known/Not Recorded”
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="EmbolizationSite">
	<sch:title>EmbolizationSite Assertions</sch:title>	

	<sch:rule id="EmbolizationSite_self_rules" context="EmbolizationSite">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="11802_EmbolizationSite" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			11802: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="11803_EmbolizationSite" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../Angiography = '3' and . = '') then(@biu != '1') else(true()) ">
			11803: Field cannot be Not Applicable when Angiography is 'Angiogram with embolization'
		</sch:assert>
		
		<sch:assert id="11804_EmbolizationSite" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../../../Angiography = ('1', '2','4')) then(every $element in ./../../item/EmbolizationSite satisfies $element/@biu='1') else(true())">
			11804: Field should be Not Applicable when Angiography is 'None' or 'Angiogram only', or 'Angiogram with stenting'
		</sch:assert>
		<sch:assert id="11805_EmbolizationSite" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu=('1','2')) then(every $element in ./../../item/EmbolizationSite satisfies $element='') else(true())">
			11805: Element cannot be Not Applicable or Not Known/Not Recorded along with any other valid value
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="AngiographyDate">
	<sch:title>AngiographyDate Assertions</sch:title>	
	
	<sch:rule id="AngiographyDate_self_rules" context="AngiographyDate">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="11903_AngiographyDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			11903: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="11904_EmbolizationSite" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../Angiography = ('2', '3','4') and . = '') then(@biu != '1') else(true()) ">
			11904: Field cannot be Not Applicable when Angiography is 'Angiogram only' or 'Angiogram with embolization' or 'Angiogram with stenting'
		</sch:assert>
		
		<sch:assert id="11905_EmbolizationSite" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../Angiography = '1') then(@biu = '1') else(true()) ">
			11905: Field should be Not Applicable when Angiography is 'None'
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="11906_AngiographyDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ./../HospitalArrivalDate)">
			11906: Angiography Date is earlier than ED/Hospital Arrival Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="11907_AngiographyDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
			11907: Angiography Date is later than Hospital Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="11908_AngiographyDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(fct:notLessThanDate(., ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ., '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ., '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, ./../AngiographyTime)) else(fct:durationParse(./../HospitalArrivalDate, ., '2') = 0)) else(true())">
			11908: Angiography Date/Time minus ED/Hospital Arrival Date/Time is greater than 24 hours
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="AngiographyTime">
	<sch:title>AngiographyTime Assertions</sch:title>	

	<sch:rule id="AngiographyTime_self_rules" context="AngiographyTime">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="12003_AngiographyTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			12003: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="12004_AngiographyTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../Angiography = ('2', '3','4') and . = '') then(@biu != '1') else(true()) ">
			12004: Field cannot be Not Applicable when Angiography is 'Angiogram only' or 'Angiogram with embolization' or 'Angiogram with stenting'
		</sch:assert>
		
		<sch:assert id="12005_AngiographyTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../Angiography = '1') then(@biu = '1') else(true()) ">
			12005: Field should be Not Applicable when Angiography is 'None'
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="12006_AngiographyTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../AngiographyDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)">
			12006: Angiography Time is earlier than ED/Hospital Arrival Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="12007_AngiographyTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../AngiographyDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
			12007: Angiography Time is later than Hospital Discharge Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="12008_AngiographyTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(fct:notLessThanDate(./../AngiographyDate, ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ./../AngiographyDate, '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ./../AngiographyDate, '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, .)) else(fct:durationParse(./../HospitalArrivalDate, ./../AngiographyDate, '2') = 0)) else(true())">
			12008: Angiography Date/Time minus ED/Hospital Arrival Date/Time is greater than 24 hours
		</sch:assert>
		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="HemorrhageControlSurgeryType">
	<sch:title>HemorrhageControlSurgeryType Assertions</sch:title>	
	
	<sch:rule id="HemorrhageControlSurgeryType_self_rules" context="HemorrhageControlSurgeryType">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="12102_HemorrhageControlSurgeryType" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			12102: Field cannot be blank
		</sch:assert>
				
		<sch:assert id="12103_HemorrhageControlSurgeryType" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours &gt; 0) or (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours &gt; 0)) then(not(@biu = '1')) else(true()) ">
			12103: Element cannot be Not Applicable when Packed Red Blood Cells or Whole Blood is greater than 0
		</sch:assert>
		
		<sch:assert id="12104_HemorrhageControlSurgeryType" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if((./../TransfusionBlood4Hours castable as xs:integer and ./../TransfusionBlood4Hours = 0) and (./../WholeBlood4Hours castable as xs:integer and ./../WholeBlood4Hours = 0)) then(@biu = '1') else(true()) ">
			12104: Element must be Not Applicable when Packed Red Blood Cells and Whole Blood are 0
		</sch:assert>
		
		<sch:assert id="12105_HemorrhageControlSurgeryType" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../TransfusionBlood4Hours/@biu = '2' and ./../WholeBlood4Hours/@biu = '2') then(@biu = '2') else(true()) ">
			12105: Element must be Not Known/Not Recorded when Packed Red Blood Cells and Whole Blood are “Not Known/Not Recorded”
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="HemorrhageControlSurgeryDate">
	<sch:title>HemorrhageControlSurgeryDate Assertions</sch:title>	
	
	<sch:rule id="HemorrhageControlSurgeryDate_self_rules" context="HemorrhageControlSurgeryDate">
		<sch:let name="ntdbElements" value="."/>		

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="12203_HemorrhageControlSurgeryDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ./../HospitalArrivalDate)">
			12203: Surgery For Hemorrhage Control Date is earlier than ED/Hospital Arrival Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="12204_HemorrhageControlSurgeryDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
			12204: Surgery For Hemorrhage Control Date is later than Hospital Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="12205_HemorrhageControlSurgeryDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu='1') then(./../HemorrhageControlSurgeryType = '1' or ./../HemorrhageControlSurgeryType = '') else(true()) ">
			12205: Field cannot be Not Applicable when Hemorrhage Control Surgery Type is not: (1) blank, (2) Not Applicable, (3) Not Known/Not Recorded or (4) None
		</sch:assert>
		
		<sch:assert id="12206_HemorrhageControlSurgeryDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../HemorrhageControlSurgeryType = '1') then(@biu = '1') else(true()) ">
			12206: Field should be Not Applicable when Hemorrhage Control Surgery Type is 'None'
		</sch:assert>

		<sch:assert id="12207_HemorrhageControlSurgeryDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			12207: Field cannot be blank
		</sch:assert>
		<sch:assert id="12208_HemorrhageControlSurgeryDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(fct:notLessThanDate(., ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ., '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ., '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, ./../HemorrhageControlSurgeryTime)) else(fct:durationParse(./../HospitalArrivalDate, ., '2') = 0)) else(true())">
			12208: Surgery for Hemorrhage Control Date/Time minus ED/Hospital Arrival Date/Time is greater than 24 hours
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="HemorrhageControlSurgeryTime">
	<sch:title>HemorrhageControlSurgeryTime Assertions</sch:title>	
	
	<sch:rule id="HemorrhageControlSurgeryTime_self_rules" context="HemorrhageControlSurgeryTime">
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="12303_HemorrhageControlSurgeryTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../HemorrhageControlSurgeryDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)">
			12303: Surgery For Hemorrhage Control Time is earlier than ED/Hospital Arrival Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="12304_HemorrhageControlSurgeryTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../HemorrhageControlSurgeryDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
			12304: Surgery For Hemorrhage Control Time is later than Hospital Discharge Time
		</sch:assert>

		<sch:let name="ntdbElements" value="."/>				
		<sch:assert id="12305_HemorrhageControlSurgeryTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu='1') then(./../HemorrhageControlSurgeryType = '1' or ./../HemorrhageControlSurgeryType = '') else(true()) ">
			12305: Field cannot be Not Applicable when Hemorrhage Control Surgery Type is not: (1) blank, (2) Not Applicable, (3) Not Known/Not Recorded or (4) None
		</sch:assert>
		
		<sch:assert id="12306_HemorrhageControlSurgeryTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../HemorrhageControlSurgeryType = '1') then(@biu = '1') else(true()) ">
			12306: Field should be Not Applicable when Hemorrhage Control Surgery Type is 'None'
		</sch:assert>
		
		<sch:assert id="12307_HemorrhageControlSurgeryTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			12307: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="12308_HemorrhageControlSurgeryTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(fct:notLessThanDate(./../HemorrhageControlSurgeryDate, ./../HospitalArrivalDate) and fct:durationParse(./../HospitalArrivalDate, ./../HemorrhageControlSurgeryDate, '2') != -1) then(if(fct:durationParse(./../HospitalArrivalDate, ./../HemorrhageControlSurgeryDate, '2') = 1) then(fct:notLessThanTime(./../HospitalArrivalTime, .)) else(fct:durationParse(./../HospitalArrivalDate, ./../HemorrhageControlSurgeryDate, '2') = 0)) else(true())">
			12308: Surgery for Hemorrhage Control Date/Time minus ED/Hospital Arrival Date/Time is greater than 24 hours
		</sch:assert>		
	</sch:rule>
</sch:pattern>
  <sch:pattern id="WithdrawalOfCare">
	<sch:title>WithdrawalOfCare Assertions</sch:title>	
	
	<sch:rule id="WithdrawalOfCare_self_rules" context="WithdrawalOfCare">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="13802_WithdrawalOfCare" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			13802: Field cannot be blank
		</sch:assert>
		
		<sch:assert id="13803_WithdrawalOfCare" role="[ERROR]" diagnostics="ntdbDiagnostic" test="not(@biu=('1'))">
			13803: Field cannot be Not Applicable
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="WithdrawalOfCareDate">
	<sch:title>WithdrawalOfCareDate Assertions</sch:title>	
	
	<sch:rule id="WithdrawalOfCareDate_self_rules" context="WithdrawalOfLifeSupportingTreatmentDate">

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="13903_WithdrawalOfCareDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(., ./../HospitalArrivalDate)">
			13903: Withdrawal of Life Supporting Treatment Date is earlier than ED/Hospital Arrival Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="13904_WithdrawalOfCareDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
			13904: Withdrawal of Life Supporting Treatment Date is later than Hospital Discharge Date
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="13905_WithdrawalOfCareDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu='1') then(./../WithdrawalOfLifeSupportingTreatment != '1') else(true()) ">
			13905: Field cannot be Not Applicable when Withdrawal of Life Supporting Treatment is 1 (Yes)
		</sch:assert>
		
		<sch:assert id="13906_WithdrawalOfCareDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../WithdrawalOfLifeSupportingTreatment = '2') then(@biu = '1') else(true()) ">
			13906: Field should be Not Applicable when Withdrawal of Life Supporting Treatment is 2 (No)
		</sch:assert>

		<sch:assert id="13907_WithdrawalOfCareDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			13907: Field cannot be blank
		</sch:assert>
	</sch:rule>
</sch:pattern>
  <sch:pattern id="WithdrawalOfCareTime">
	<sch:title>WithdrawalOfCareTime Assertions</sch:title>	
	
	<sch:rule id="WithdrawalOfCareTime_self_rules" context="WithdrawalOfCareTime">
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="14003_WithdrawalOfCareTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../WithdrawalOfLifeSupportingTreatmentDate, ./../HospitalArrivalDate) or fct:notLessThanTime(., ./../HospitalArrivalTime)">
			14003: Withdrawal of Life Supporting Treatment Time is earlier than ED/Hospital Arrival Time
		</sch:assert>
		
		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="14004_WithdrawalOfCareTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../WithdrawalOfLifeSupportingTreatmentDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
			14004: Withdrawal of Life Supporting Treatment Time is later than Hospital Discharge Time
		</sch:assert>

		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="14005_WithdrawalOfCareTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu='1') then(./../WithdrawalOfLifeSupportingTreatment != '1') else(true()) ">
			14005: Field cannot be Not Applicable when Withdrawal of Life Supporting Treatment is 1 (Yes)
		</sch:assert>
		
		<sch:assert id="14006_WithdrawalOfCareTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../WithdrawalOfLifeSupportingTreatment = '2') then(@biu = '1') else(true()) ">
			14006: Field should be Not Applicable when Withdrawal of Life Supporting Treatment is 2 (No)
		</sch:assert>
		
		<sch:assert id="14007_WithdrawalOfCareTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			14007: Field cannot be blank
		</sch:assert>
		
	</sch:rule>
</sch:pattern>
<sch:pattern id="AntibioticTherapy">
	<sch:title>AntibioticTherapy Assertions</sch:title>	
	<sch:rule id="AntibioticTherapy_self_rules" context="AntibioticTherapy">
		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="20702_AntibioticTherapy" role="[ERROR]" diagnostics="ntdbDiagnostic" test=". != '' or @biu=('1', '2')">
			20702: Field cannot be blank
		</sch:assert>
	</sch:rule>
</sch:pattern>

<sch:pattern id="AntibioticTherapyDate">
	<sch:title>AntibioticTherapyDate Assertions</sch:title>	
	<sch:rule id="AntibioticTherapyDate_self_rules" context="AntibioticTherapyDate">

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="20807_AntibioticTherapyDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notLessThanDate(./../HospitalDischargeOrdersWrittenDate, .)">
			20807: Antibiotic Therapy Date is later than Hospital Discharge Date
		</sch:assert>

		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="20803_AntibioticTherapyDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu='1') then(./../AntibioticTherapy != '1') else(true()) ">
			20903: Element cannot be Not Applicable when Antibiotic Therapy is 1. Yes
		</sch:assert>
		
		<sch:assert id="20804_AntibioticTherapyDate" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../AntibioticTherapy = '2') then(@biu = '1') else(true()) ">
			20804: Element must be Not Applicable when Antibiotic Therapy is 2. No
		</sch:assert>
	</sch:rule>	
</sch:pattern>

<sch:pattern id="AntibioticTherapyTime">
	<sch:title>AntibioticTherapyTime Assertions</sch:title>	
	<sch:rule id="AntibioticTherapyTime_self_rules" context="AntibioticTherapyTime">

		<sch:let name="ntdbElements" value="."/>
		<sch:assert id="20907_AntibioticTherapyTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="fct:notEqualDate(./../AntibioticTherapyDate, ./../HospitalDischargeOrdersWrittenDate) or fct:notLessThanTime(./../HospitalDischargeOrdersWrittenTime, .)">
			20907: Antibiotic Therapy Time is later than Hospital Discharge Time
		</sch:assert>

		<sch:let name="ntdbElements" value="."/>		
		<sch:assert id="20903_AntibioticTherapyTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(@biu='1') then(./../AntibioticTherapy != '1') else(true()) ">
			20903: Element cannot be Not Applicable when Antibiotic Therapy is 1. Yes
		</sch:assert>
		
		<sch:assert id="20904_AntibioticTherapyTime" role="[ERROR]" diagnostics="ntdbDiagnostic" test="if(./../AntibioticTherapy = '2') then(@biu = '1') else(true()) ">
			20904: Element must be Not Applicable when Antibiotic Therapy is 2. No
		</sch:assert>
	</sch:rule>	
</sch:pattern>


  

  <sch:diagnostics>

    

    <sch:diagnostic id="ntdbDiagnostic">
	<ntdbDiagnostic xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
		<record>
			<xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:PatientId"/>
			<xsl:copy-of select="ancestor-or-self::*:ItdxRecord/*:FacilityId"/>
		</record>
		<elements>
			<xsl:for-each select="$ntdbElements">
				<xsl:element name="element">
					<xsl:attribute name="location">
						<xsl:apply-templates select="." mode="schematron-get-full-path"/>
					</xsl:attribute>
					<xsl:for-each select="@*">
						<xsl:attribute name="{name()}">
							<xsl:value-of select="."/>
						</xsl:attribute>
					</xsl:for-each>
					<xsl:if test="not(*)">
						<xsl:value-of select="."/>
					</xsl:if>
				</xsl:element>
			</xsl:for-each>
		</elements>
	</ntdbDiagnostic>
</sch:diagnostic>

  </sch:diagnostics>

</sch:schema>
